/********************************************************************************
** Form generated from reading UI file 'pressurecurvedialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PRESSURECURVEDIALOG_H
#define UI_PRESSURECURVEDIALOG_H

#include <QtCore/QLocale>
#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "pressurecurvewidget.h"

QT_BEGIN_NAMESPACE

class Ui_PressureCurveDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *explaining_Label;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer_2;
    Wacom::PressureCurveWidget *pc_Widget;
    QSpacerItem *horizontalSpacer_3;
    QHBoxLayout *horizontalLayout;
    QLabel *pc_Label;
    QLabel *pc_Values;
    QSpacerItem *horizontalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *PressureCurveDialog)
    {
        if (PressureCurveDialog->objectName().isEmpty())
            PressureCurveDialog->setObjectName("PressureCurveDialog");
        PressureCurveDialog->setWindowModality(Qt::NonModal);
        PressureCurveDialog->resize(446, 512);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(PressureCurveDialog->sizePolicy().hasHeightForWidth());
        PressureCurveDialog->setSizePolicy(sizePolicy);
        PressureCurveDialog->setLocale(QLocale(QLocale::English, QLocale::UnitedKingdom));
        PressureCurveDialog->setSizeGripEnabled(false);
        verticalLayout = new QVBoxLayout(PressureCurveDialog);
        verticalLayout->setObjectName("verticalLayout");
        explaining_Label = new QLabel(PressureCurveDialog);
        explaining_Label->setObjectName("explaining_Label");
        explaining_Label->setScaledContents(false);
        explaining_Label->setWordWrap(true);

        verticalLayout->addWidget(explaining_Label);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        pc_Widget = new Wacom::PressureCurveWidget(PressureCurveDialog);
        pc_Widget->setObjectName("pc_Widget");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(pc_Widget->sizePolicy().hasHeightForWidth());
        pc_Widget->setSizePolicy(sizePolicy1);
        pc_Widget->setMinimumSize(QSize(300, 300));
        pc_Widget->setMaximumSize(QSize(300, 300));

        horizontalLayout_2->addWidget(pc_Widget);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_3);


        verticalLayout->addLayout(horizontalLayout_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        pc_Label = new QLabel(PressureCurveDialog);
        pc_Label->setObjectName("pc_Label");

        horizontalLayout->addWidget(pc_Label);

        pc_Values = new QLabel(PressureCurveDialog);
        pc_Values->setObjectName("pc_Values");

        horizontalLayout->addWidget(pc_Values);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);

        buttonBox = new QDialogButtonBox(PressureCurveDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(PressureCurveDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, PressureCurveDialog, qOverload<>(&QDialog::reject));
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, PressureCurveDialog, qOverload<>(&QDialog::accept));

        QMetaObject::connectSlotsByName(PressureCurveDialog);
    } // setupUi

    void retranslateUi(QDialog *PressureCurveDialog)
    {
        PressureCurveDialog->setWindowTitle(tr2i18n("Press Curve Settings", nullptr));
        explaining_Label->setText(tr2i18n("The presscurve defines how the pen press is handled.\n"
"Drag around the dots to change the behavior\n"
"Use the stylus inside the Widget to see the pressure changes.", nullptr));
        pc_Label->setText(tr2i18n("Current Presscurve:", nullptr));
        pc_Values->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class PressureCurveDialog: public Ui_PressureCurveDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PRESSURECURVEDIALOG_H

