/********************************************************************************
** Form generated from reading UI file 'dialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DIALOG_H
#define UI_DIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_Dialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label_3;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QLabel *label_5;
    QHBoxLayout *horizontalLayout;
    QComboBox *listTablets;
    QPushButton *refreshButton;
    QLabel *label_4;
    QLabel *listSerialId;
    QLabel *label;
    QLabel *listDevices;
    QHBoxLayout *horizontalLayout_2;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_2;
    QCheckBox *hasTouchRing;
    QCheckBox *hasStatusLEDsRight;
    QCheckBox *hasTouchStripLeft;
    QCheckBox *hasTouchStripRight;
    QCheckBox *hasStatusLEDsLeft;
    QCheckBox *hasWheel;
    QSpacerItem *verticalSpacer_3;
    QGroupBox *groupBox_3;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_2;
    QSpinBox *expressKeyNumbers;
    QPushButton *mapButtons;
    QLabel *buttonMappingLabel;
    QSpacerItem *verticalSpacer_2;
    QGroupBox *groupBox_4;
    QVBoxLayout *verticalLayout_3;
    QRadioButton *radioNormalTablet;
    QHBoxLayout *horizontalLayout_4;
    QRadioButton *radioParentTablet;
    QComboBox *comboTouchSensor;
    QRadioButton *radioTouchSensor;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *Dialog)
    {
        if (Dialog->objectName().isEmpty())
            Dialog->setObjectName("Dialog");
        Dialog->resize(580, 613);
        verticalLayout = new QVBoxLayout(Dialog);
        verticalLayout->setSpacing(6);
        verticalLayout->setContentsMargins(11, 11, 11, 11);
        verticalLayout->setObjectName("verticalLayout");
        label_3 = new QLabel(Dialog);
        label_3->setObjectName("label_3");

        verticalLayout->addWidget(label_3);

        groupBox = new QGroupBox(Dialog);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setSpacing(6);
        gridLayout->setContentsMargins(11, 11, 11, 11);
        gridLayout->setObjectName("gridLayout");
        label_5 = new QLabel(groupBox);
        label_5->setObjectName("label_5");
        QFont font;
        font.setBold(false);
        label_5->setFont(font);

        gridLayout->addWidget(label_5, 0, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(6);
        horizontalLayout->setObjectName("horizontalLayout");
        listTablets = new QComboBox(groupBox);
        listTablets->setObjectName("listTablets");

        horizontalLayout->addWidget(listTablets);

        refreshButton = new QPushButton(groupBox);
        refreshButton->setObjectName("refreshButton");

        horizontalLayout->addWidget(refreshButton);

        horizontalLayout->setStretch(0, 1);

        gridLayout->addLayout(horizontalLayout, 0, 1, 1, 1);

        label_4 = new QLabel(groupBox);
        label_4->setObjectName("label_4");
        label_4->setFont(font);

        gridLayout->addWidget(label_4, 1, 0, 1, 1);

        listSerialId = new QLabel(groupBox);
        listSerialId->setObjectName("listSerialId");

        gridLayout->addWidget(listSerialId, 1, 1, 1, 1);

        label = new QLabel(groupBox);
        label->setObjectName("label");
        label->setFont(font);

        gridLayout->addWidget(label, 2, 0, 1, 1);

        listDevices = new QLabel(groupBox);
        listDevices->setObjectName("listDevices");

        gridLayout->addWidget(listDevices, 2, 1, 1, 1);

        gridLayout->setColumnStretch(1, 1);

        verticalLayout->addWidget(groupBox);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(6);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        groupBox_2 = new QGroupBox(Dialog);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout_2 = new QGridLayout(groupBox_2);
        gridLayout_2->setSpacing(6);
        gridLayout_2->setContentsMargins(11, 11, 11, 11);
        gridLayout_2->setObjectName("gridLayout_2");
        hasTouchRing = new QCheckBox(groupBox_2);
        hasTouchRing->setObjectName("hasTouchRing");

        gridLayout_2->addWidget(hasTouchRing, 2, 0, 1, 1);

        hasStatusLEDsRight = new QCheckBox(groupBox_2);
        hasStatusLEDsRight->setObjectName("hasStatusLEDsRight");

        gridLayout_2->addWidget(hasStatusLEDsRight, 6, 0, 1, 1);

        hasTouchStripLeft = new QCheckBox(groupBox_2);
        hasTouchStripLeft->setObjectName("hasTouchStripLeft");

        gridLayout_2->addWidget(hasTouchStripLeft, 3, 0, 1, 1);

        hasTouchStripRight = new QCheckBox(groupBox_2);
        hasTouchStripRight->setObjectName("hasTouchStripRight");

        gridLayout_2->addWidget(hasTouchStripRight, 4, 0, 1, 1);

        hasStatusLEDsLeft = new QCheckBox(groupBox_2);
        hasStatusLEDsLeft->setObjectName("hasStatusLEDsLeft");

        gridLayout_2->addWidget(hasStatusLEDsLeft, 5, 0, 1, 1);

        hasWheel = new QCheckBox(groupBox_2);
        hasWheel->setObjectName("hasWheel");

        gridLayout_2->addWidget(hasWheel, 1, 0, 1, 1);

        verticalSpacer_3 = new QSpacerItem(0, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_3, 7, 0, 1, 1);


        horizontalLayout_2->addWidget(groupBox_2);

        groupBox_3 = new QGroupBox(Dialog);
        groupBox_3->setObjectName("groupBox_3");
        groupBox_3->setFont(font);
        verticalLayout_2 = new QVBoxLayout(groupBox_3);
        verticalLayout_2->setSpacing(6);
        verticalLayout_2->setContentsMargins(11, 11, 11, 11);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setSpacing(6);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        label_2 = new QLabel(groupBox_3);
        label_2->setObjectName("label_2");

        horizontalLayout_3->addWidget(label_2);

        expressKeyNumbers = new QSpinBox(groupBox_3);
        expressKeyNumbers->setObjectName("expressKeyNumbers");

        horizontalLayout_3->addWidget(expressKeyNumbers);


        verticalLayout_2->addLayout(horizontalLayout_3);

        mapButtons = new QPushButton(groupBox_3);
        mapButtons->setObjectName("mapButtons");

        verticalLayout_2->addWidget(mapButtons);

        buttonMappingLabel = new QLabel(groupBox_3);
        buttonMappingLabel->setObjectName("buttonMappingLabel");

        verticalLayout_2->addWidget(buttonMappingLabel);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_2);


        horizontalLayout_2->addWidget(groupBox_3);


        verticalLayout->addLayout(horizontalLayout_2);

        groupBox_4 = new QGroupBox(Dialog);
        groupBox_4->setObjectName("groupBox_4");
        verticalLayout_3 = new QVBoxLayout(groupBox_4);
        verticalLayout_3->setSpacing(6);
        verticalLayout_3->setContentsMargins(11, 11, 11, 11);
        verticalLayout_3->setObjectName("verticalLayout_3");
        radioNormalTablet = new QRadioButton(groupBox_4);
        radioNormalTablet->setObjectName("radioNormalTablet");
        radioNormalTablet->setChecked(true);

        verticalLayout_3->addWidget(radioNormalTablet);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setSpacing(6);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        radioParentTablet = new QRadioButton(groupBox_4);
        radioParentTablet->setObjectName("radioParentTablet");

        horizontalLayout_4->addWidget(radioParentTablet);

        comboTouchSensor = new QComboBox(groupBox_4);
        comboTouchSensor->setObjectName("comboTouchSensor");

        horizontalLayout_4->addWidget(comboTouchSensor);


        verticalLayout_3->addLayout(horizontalLayout_4);

        radioTouchSensor = new QRadioButton(groupBox_4);
        radioTouchSensor->setObjectName("radioTouchSensor");

        verticalLayout_3->addWidget(radioTouchSensor);


        verticalLayout->addWidget(groupBox_4);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(Dialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Close|QDialogButtonBox::Save|QDialogButtonBox::SaveAll);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(Dialog);

        QMetaObject::connectSlotsByName(Dialog);
    } // setupUi

    void retranslateUi(QDialog *Dialog)
    {
        Dialog->setWindowTitle(tr2i18n("Wacom Tablet detection", nullptr));
        label_3->setText(tr2i18n("Connect your Tablet and click on Refresh to detect it.", nullptr));
        groupBox->setTitle(tr2i18n("Tablet Selection", nullptr));
        label_5->setText(tr2i18n("Detected Tablets:", nullptr));
        refreshButton->setText(tr2i18n("Refresh", nullptr));
        label_4->setText(tr2i18n("Serial No.:", nullptr));
        listSerialId->setText(QString());
        label->setText(tr2i18n("Devices: ", nullptr));
        listDevices->setText(QString());
        groupBox_2->setTitle(tr2i18n("Tablet Features", nullptr));
        hasTouchRing->setText(tr2i18n("has TouchRing", nullptr));
        hasStatusLEDsRight->setText(tr2i18n("has Status LEDs right", nullptr));
        hasTouchStripLeft->setText(tr2i18n("has Touchstrip Left", nullptr));
        hasTouchStripRight->setText(tr2i18n("has Touchstrip Right", nullptr));
        hasStatusLEDsLeft->setText(tr2i18n("has Status LEDs left", nullptr));
        hasWheel->setText(tr2i18n("has Wheel", nullptr));
        groupBox_3->setTitle(tr2i18n("Button mapping", nullptr));
        label_2->setText(tr2i18n("Number of available Express Keys:", nullptr));
        mapButtons->setText(tr2i18n("Map Hardware Buttons", nullptr));
        buttonMappingLabel->setText(QString());
        groupBox_4->setTitle(tr2i18n("Touch sensor", nullptr));
        radioNormalTablet->setText(tr2i18n("&Normal tablet", nullptr));
        radioParentTablet->setText(tr2i18n("&Multi-device tablet, pen sensor. Touch sensor is:", nullptr));
        radioTouchSensor->setText(tr2i18n("Multi-&device tablet, touch sensor", nullptr));
    } // retranslateUi

};

namespace Ui {
    class Dialog: public Ui_Dialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DIALOG_H

