/********************************************************************************
** Form generated from reading UI file 'styluspagewidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_STYLUSPAGEWIDGET_H
#define UI_STYLUSPAGEWIDGET_H

#include <QtCore/QLocale>
#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "buttonactionselectorwidget.h"

QT_BEGIN_NAMESPACE

class Ui_StylusPageWidget
{
public:
    QVBoxLayout *verticalLayout_6;
    QGridLayout *penWidgetGridLayout;
    QGroupBox *buttonGroupBox;
    QFormLayout *formLayout_3;
    QLabel *labelButton3;
    Wacom::ButtonActionSelectorWidget *button3ActionSelector;
    QLabel *labelButton2;
    Wacom::ButtonActionSelectorWidget *button2ActionSelector;
    QLabel *labelButton1;
    Wacom::ButtonActionSelectorWidget *button1ActionSelector;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *tpcSpacer;
    QCheckBox *tpcCheckBox;
    QGroupBox *eraserBox;
    QVBoxLayout *verticalLayout_2;
    QVBoxLayout *eraserFeelSliderLayout;
    QSlider *eraserSlider;
    QHBoxLayout *eraserFeelSliderLablesLayout;
    QLabel *labelSlow_2;
    QSpacerItem *eraserFeelSliderLabelsSpacer;
    QLabel *labelFast_2;
    QHBoxLayout *eraserPressureButtonLayout;
    QSpacerItem *eraserPressureButtonSpacer;
    QPushButton *eraserPressureButton;
    QSpacerItem *verticalSpacer_2;
    QGroupBox *tipFeelGroupBox;
    QVBoxLayout *verticalLayout_4;
    QVBoxLayout *verticalLayout_5;
    QSlider *tipSlider;
    QHBoxLayout *horizontalLayout_5;
    QLabel *labelSlow_3;
    QSpacerItem *horizontalSpacer_5;
    QLabel *labelFast_3;
    QHBoxLayout *horizontalLayout_6;
    QSpacerItem *horizontalSpacer_7;
    QPushButton *tipPressureButton;
    QGroupBox *groupBoxRawSample;
    QVBoxLayout *verticalLayout;
    QSlider *horizontalSliderRawSample;
    QHBoxLayout *horizontalLayout;
    QLabel *labelMinRawSample;
    QSpacerItem *horizontalSpacer;
    QLabel *labelMaxRawSample;
    QGroupBox *groupBoxSupress;
    QVBoxLayout *verticalLayout_3;
    QSlider *horizontalSliderSuppress;
    QHBoxLayout *horizontalLayout_3;
    QLabel *labelMinSuppress;
    QSpacerItem *horizontalSpacer_2;
    QLabel *labelMaxSuppress;
    QVBoxLayout *penLayout;
    QSpacerItem *penTopSpacer;
    QLabel *penLabel;
    QSpacerItem *penBottomSpacer;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *StylusPageWidget)
    {
        if (StylusPageWidget->objectName().isEmpty())
            StylusPageWidget->setObjectName("StylusPageWidget");
        StylusPageWidget->resize(629, 673);
        StylusPageWidget->setLocale(QLocale(QLocale::English, QLocale::UnitedKingdom));
        verticalLayout_6 = new QVBoxLayout(StylusPageWidget);
        verticalLayout_6->setObjectName("verticalLayout_6");
        penWidgetGridLayout = new QGridLayout();
        penWidgetGridLayout->setSpacing(10);
        penWidgetGridLayout->setObjectName("penWidgetGridLayout");
        buttonGroupBox = new QGroupBox(StylusPageWidget);
        buttonGroupBox->setObjectName("buttonGroupBox");
        formLayout_3 = new QFormLayout(buttonGroupBox);
        formLayout_3->setObjectName("formLayout_3");
        labelButton3 = new QLabel(buttonGroupBox);
        labelButton3->setObjectName("labelButton3");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(labelButton3->sizePolicy().hasHeightForWidth());
        labelButton3->setSizePolicy(sizePolicy);
        labelButton3->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        formLayout_3->setWidget(0, QFormLayout::ItemRole::LabelRole, labelButton3);

        button3ActionSelector = new Wacom::ButtonActionSelectorWidget(buttonGroupBox);
        button3ActionSelector->setObjectName("button3ActionSelector");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::FieldRole, button3ActionSelector);

        labelButton2 = new QLabel(buttonGroupBox);
        labelButton2->setObjectName("labelButton2");
        sizePolicy.setHeightForWidth(labelButton2->sizePolicy().hasHeightForWidth());
        labelButton2->setSizePolicy(sizePolicy);
        labelButton2->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        formLayout_3->setWidget(3, QFormLayout::ItemRole::LabelRole, labelButton2);

        button2ActionSelector = new Wacom::ButtonActionSelectorWidget(buttonGroupBox);
        button2ActionSelector->setObjectName("button2ActionSelector");

        formLayout_3->setWidget(3, QFormLayout::ItemRole::FieldRole, button2ActionSelector);

        labelButton1 = new QLabel(buttonGroupBox);
        labelButton1->setObjectName("labelButton1");
        sizePolicy.setHeightForWidth(labelButton1->sizePolicy().hasHeightForWidth());
        labelButton1->setSizePolicy(sizePolicy);
        labelButton1->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        formLayout_3->setWidget(4, QFormLayout::ItemRole::LabelRole, labelButton1);

        button1ActionSelector = new Wacom::ButtonActionSelectorWidget(buttonGroupBox);
        button1ActionSelector->setObjectName("button1ActionSelector");

        formLayout_3->setWidget(4, QFormLayout::ItemRole::FieldRole, button1ActionSelector);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        tpcSpacer = new QSpacerItem(32, 0, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(tpcSpacer);

        tpcCheckBox = new QCheckBox(buttonGroupBox);
        tpcCheckBox->setObjectName("tpcCheckBox");

        horizontalLayout_2->addWidget(tpcCheckBox);


        formLayout_3->setLayout(5, QFormLayout::ItemRole::FieldRole, horizontalLayout_2);


        penWidgetGridLayout->addWidget(buttonGroupBox, 1, 2, 1, 1);

        eraserBox = new QGroupBox(StylusPageWidget);
        eraserBox->setObjectName("eraserBox");
        verticalLayout_2 = new QVBoxLayout(eraserBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        eraserFeelSliderLayout = new QVBoxLayout();
        eraserFeelSliderLayout->setObjectName("eraserFeelSliderLayout");
        eraserSlider = new QSlider(eraserBox);
        eraserSlider->setObjectName("eraserSlider");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(eraserSlider->sizePolicy().hasHeightForWidth());
        eraserSlider->setSizePolicy(sizePolicy1);
        eraserSlider->setMinimumSize(QSize(0, 0));
        eraserSlider->setMinimum(0);
        eraserSlider->setMaximum(2000);
        eraserSlider->setSingleStep(20);
        eraserSlider->setValue(27);
        eraserSlider->setOrientation(Qt::Horizontal);
        eraserSlider->setTickPosition(QSlider::TicksBelow);
        eraserSlider->setTickInterval(250);

        eraserFeelSliderLayout->addWidget(eraserSlider);

        eraserFeelSliderLablesLayout = new QHBoxLayout();
        eraserFeelSliderLablesLayout->setObjectName("eraserFeelSliderLablesLayout");
        labelSlow_2 = new QLabel(eraserBox);
        labelSlow_2->setObjectName("labelSlow_2");

        eraserFeelSliderLablesLayout->addWidget(labelSlow_2);

        eraserFeelSliderLabelsSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Minimum);

        eraserFeelSliderLablesLayout->addItem(eraserFeelSliderLabelsSpacer);

        labelFast_2 = new QLabel(eraserBox);
        labelFast_2->setObjectName("labelFast_2");

        eraserFeelSliderLablesLayout->addWidget(labelFast_2);


        eraserFeelSliderLayout->addLayout(eraserFeelSliderLablesLayout);


        verticalLayout_2->addLayout(eraserFeelSliderLayout);

        eraserPressureButtonLayout = new QHBoxLayout();
        eraserPressureButtonLayout->setObjectName("eraserPressureButtonLayout");
        eraserPressureButtonSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Minimum);

        eraserPressureButtonLayout->addItem(eraserPressureButtonSpacer);

        eraserPressureButton = new QPushButton(eraserBox);
        eraserPressureButton->setObjectName("eraserPressureButton");

        eraserPressureButtonLayout->addWidget(eraserPressureButton);


        verticalLayout_2->addLayout(eraserPressureButtonLayout);

        verticalSpacer_2 = new QSpacerItem(1, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        verticalLayout_2->addItem(verticalSpacer_2);


        penWidgetGridLayout->addWidget(eraserBox, 0, 2, 1, 1);

        tipFeelGroupBox = new QGroupBox(StylusPageWidget);
        tipFeelGroupBox->setObjectName("tipFeelGroupBox");
        verticalLayout_4 = new QVBoxLayout(tipFeelGroupBox);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_5 = new QVBoxLayout();
        verticalLayout_5->setObjectName("verticalLayout_5");
        tipSlider = new QSlider(tipFeelGroupBox);
        tipSlider->setObjectName("tipSlider");
        sizePolicy1.setHeightForWidth(tipSlider->sizePolicy().hasHeightForWidth());
        tipSlider->setSizePolicy(sizePolicy1);
        tipSlider->setMinimumSize(QSize(0, 0));
        tipSlider->setMinimum(0);
        tipSlider->setMaximum(2000);
        tipSlider->setSingleStep(20);
        tipSlider->setValue(27);
        tipSlider->setOrientation(Qt::Horizontal);
        tipSlider->setTickPosition(QSlider::TicksBelow);
        tipSlider->setTickInterval(250);

        verticalLayout_5->addWidget(tipSlider);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        labelSlow_3 = new QLabel(tipFeelGroupBox);
        labelSlow_3->setObjectName("labelSlow_3");

        horizontalLayout_5->addWidget(labelSlow_3);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_5);

        labelFast_3 = new QLabel(tipFeelGroupBox);
        labelFast_3->setObjectName("labelFast_3");

        horizontalLayout_5->addWidget(labelFast_3);


        verticalLayout_5->addLayout(horizontalLayout_5);


        verticalLayout_4->addLayout(verticalLayout_5);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_7);

        tipPressureButton = new QPushButton(tipFeelGroupBox);
        tipPressureButton->setObjectName("tipPressureButton");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(tipPressureButton->sizePolicy().hasHeightForWidth());
        tipPressureButton->setSizePolicy(sizePolicy2);

        horizontalLayout_6->addWidget(tipPressureButton);


        verticalLayout_4->addLayout(horizontalLayout_6);


        penWidgetGridLayout->addWidget(tipFeelGroupBox, 2, 2, 1, 1);

        groupBoxRawSample = new QGroupBox(StylusPageWidget);
        groupBoxRawSample->setObjectName("groupBoxRawSample");
        groupBoxRawSample->setMinimumSize(QSize(0, 0));
        verticalLayout = new QVBoxLayout(groupBoxRawSample);
        verticalLayout->setObjectName("verticalLayout");
        horizontalSliderRawSample = new QSlider(groupBoxRawSample);
        horizontalSliderRawSample->setObjectName("horizontalSliderRawSample");
        horizontalSliderRawSample->setMinimum(1);
        horizontalSliderRawSample->setMaximum(20);
        horizontalSliderRawSample->setPageStep(10);
        horizontalSliderRawSample->setValue(4);
        horizontalSliderRawSample->setOrientation(Qt::Horizontal);
        horizontalSliderRawSample->setTickPosition(QSlider::TicksBelow);
        horizontalSliderRawSample->setTickInterval(1);

        verticalLayout->addWidget(horizontalSliderRawSample);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        labelMinRawSample = new QLabel(groupBoxRawSample);
        labelMinRawSample->setObjectName("labelMinRawSample");

        horizontalLayout->addWidget(labelMinRawSample);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        labelMaxRawSample = new QLabel(groupBoxRawSample);
        labelMaxRawSample->setObjectName("labelMaxRawSample");

        horizontalLayout->addWidget(labelMaxRawSample);


        verticalLayout->addLayout(horizontalLayout);


        penWidgetGridLayout->addWidget(groupBoxRawSample, 3, 2, 1, 1);

        groupBoxSupress = new QGroupBox(StylusPageWidget);
        groupBoxSupress->setObjectName("groupBoxSupress");
        groupBoxSupress->setMinimumSize(QSize(0, 0));
        verticalLayout_3 = new QVBoxLayout(groupBoxSupress);
        verticalLayout_3->setObjectName("verticalLayout_3");
        horizontalSliderSuppress = new QSlider(groupBoxSupress);
        horizontalSliderSuppress->setObjectName("horizontalSliderSuppress");
        horizontalSliderSuppress->setMinimum(0);
        horizontalSliderSuppress->setMaximum(20);
        horizontalSliderSuppress->setPageStep(7);
        horizontalSliderSuppress->setValue(2);
        horizontalSliderSuppress->setOrientation(Qt::Horizontal);
        horizontalSliderSuppress->setTickPosition(QSlider::TicksBelow);
        horizontalSliderSuppress->setTickInterval(1);

        verticalLayout_3->addWidget(horizontalSliderSuppress);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        labelMinSuppress = new QLabel(groupBoxSupress);
        labelMinSuppress->setObjectName("labelMinSuppress");

        horizontalLayout_3->addWidget(labelMinSuppress);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_2);

        labelMaxSuppress = new QLabel(groupBoxSupress);
        labelMaxSuppress->setObjectName("labelMaxSuppress");

        horizontalLayout_3->addWidget(labelMaxSuppress);


        verticalLayout_3->addLayout(horizontalLayout_3);


        penWidgetGridLayout->addWidget(groupBoxSupress, 4, 2, 1, 1);

        penLayout = new QVBoxLayout();
        penLayout->setSpacing(7);
        penLayout->setObjectName("penLayout");
        penTopSpacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        penLayout->addItem(penTopSpacer);

        penLabel = new QLabel(StylusPageWidget);
        penLabel->setObjectName("penLabel");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(penLabel->sizePolicy().hasHeightForWidth());
        penLabel->setSizePolicy(sizePolicy3);
        penLabel->setMinimumSize(QSize(40, 300));
        penLabel->setFrameShape(QFrame::NoFrame);

        penLayout->addWidget(penLabel);

        penBottomSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        penLayout->addItem(penBottomSpacer);


        penWidgetGridLayout->addLayout(penLayout, 0, 0, 5, 1);


        verticalLayout_6->addLayout(penWidgetGridLayout);

        verticalSpacer = new QSpacerItem(20, 11, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_6->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        labelSlow_2->setBuddy(eraserSlider);
        labelFast_2->setBuddy(eraserSlider);
        labelSlow_3->setBuddy(tipSlider);
        labelFast_3->setBuddy(tipSlider);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(eraserSlider, eraserPressureButton);
        QWidget::setTabOrder(eraserPressureButton, tipSlider);
        QWidget::setTabOrder(tipSlider, tipPressureButton);

        retranslateUi(StylusPageWidget);
        QObject::connect(eraserSlider, SIGNAL(valueChanged(int)), StylusPageWidget, SLOT(onProfileChanged()));
        QObject::connect(tipSlider, SIGNAL(valueChanged(int)), StylusPageWidget, SLOT(onProfileChanged()));
        QObject::connect(eraserPressureButton, SIGNAL(clicked()), StylusPageWidget, SLOT(onChangeEraserPressureCurve()));
        QObject::connect(tpcCheckBox, SIGNAL(toggled(bool)), StylusPageWidget, SLOT(onProfileChanged()));
        QObject::connect(tipPressureButton, SIGNAL(clicked()), StylusPageWidget, SLOT(onChangeTipPressureCurve()));
        QObject::connect(horizontalSliderRawSample, SIGNAL(valueChanged(int)), StylusPageWidget, SLOT(onProfileChanged()));
        QObject::connect(horizontalSliderSuppress, SIGNAL(valueChanged(int)), StylusPageWidget, SLOT(onProfileChanged()));

        QMetaObject::connectSlotsByName(StylusPageWidget);
    } // setupUi

    void retranslateUi(QWidget *StylusPageWidget)
    {
        StylusPageWidget->setWindowTitle(tr2i18n("Pen Settings", nullptr));
#if QT_CONFIG(tooltip)
        buttonGroupBox->setToolTip(tr2i18n("Defines the button action on the stylus.", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonGroupBox->setTitle(tr2i18n("Button Settings", nullptr));
        labelButton3->setText(tr2i18n("Button 3", nullptr));
        labelButton2->setText(tr2i18n("Button 2", nullptr));
        labelButton1->setText(tr2i18n("Button 1", nullptr));
#if QT_CONFIG(tooltip)
        tpcCheckBox->setToolTip(tr2i18n("If selected, the stylus must be in contact with the tablet for a stylus side button to work.\n"
"If deselected, stylus buttons will work once the stylus is in proximity of the tablet.", nullptr));
#endif // QT_CONFIG(tooltip)
        tpcCheckBox->setText(tr2i18n("Tap to execute action.", nullptr));
#if QT_CONFIG(tooltip)
        eraserBox->setToolTip(tr2i18n("Sets eraser pressure threshold.", nullptr));
#endif // QT_CONFIG(tooltip)
        eraserBox->setTitle(tr2i18n("Eraser Feel", nullptr));
#if QT_CONFIG(tooltip)
        eraserSlider->setToolTip(tr2i18n("Set the minimum pressure necessary to generate a Button event for the stylus/tip, eraser, or touch.\n"
" The pressure levels of all tablets are normalized to 2048 levels irregardless of the actual hardware supported levels.\n"
"This parameter is independent of the PressureCurve parameter.", nullptr));
#endif // QT_CONFIG(tooltip)
        labelSlow_2->setText(tr2i18n("Soft", "slow movement of the cursor (minimal value)"));
        labelFast_2->setText(tr2i18n("Firm", "fast movement of the cursor (maximal value)"));
#if QT_CONFIG(tooltip)
        eraserPressureButton->setToolTip(tr2i18n("Defines the pressure sensitivity with a bezier curve", nullptr));
#endif // QT_CONFIG(tooltip)
        eraserPressureButton->setText(tr2i18n("Edit Pressure Curve...", nullptr));
#if QT_CONFIG(tooltip)
        tipFeelGroupBox->setToolTip(tr2i18n("Sets stylus pressure threshold.", nullptr));
#endif // QT_CONFIG(tooltip)
        tipFeelGroupBox->setTitle(tr2i18n("Tip Feel", nullptr));
#if QT_CONFIG(tooltip)
        tipSlider->setToolTip(tr2i18n("Set the minimum pressure necessary to generate a Button event for the stylus/tip, eraser, or touch.\n"
" The pressure levels of all tablets are normalized to 2048 levels irregardless of the actual hardware supported levels.\n"
"This parameter is independent of the PressureCurve parameter.", nullptr));
#endif // QT_CONFIG(tooltip)
        labelSlow_3->setText(tr2i18n("Soft", "slow movement of the cursor (minimal value)"));
        labelFast_3->setText(tr2i18n("Firm", "fast movement of the cursor (maximal value)"));
#if QT_CONFIG(tooltip)
        tipPressureButton->setToolTip(tr2i18n("Defines the pressure sensitivity with a bezier curve", nullptr));
#endif // QT_CONFIG(tooltip)
        tipPressureButton->setText(tr2i18n("Edit Pressure Curve...", nullptr));
#if QT_CONFIG(tooltip)
        groupBoxRawSample->setToolTip(tr2i18n("Number of raw data used to filter the points (default is 4)", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBoxRawSample->setTitle(tr2i18n("Raw Sample Rate", nullptr));
#if QT_CONFIG(tooltip)
        horizontalSliderRawSample->setToolTip(tr2i18n("Number of raw data used to filter the points (default is 4)", nullptr));
#endif // QT_CONFIG(tooltip)
        labelMinRawSample->setText(tr2i18n("1", nullptr));
        labelMaxRawSample->setText(tr2i18n("20", nullptr));
#if QT_CONFIG(tooltip)
        groupBoxSupress->setToolTip(tr2i18n("Number of points trimmed (default is 2)", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBoxSupress->setTitle(tr2i18n("Suppress Rate", nullptr));
        labelMinSuppress->setText(tr2i18n("0", nullptr));
        labelMaxSuppress->setText(tr2i18n("20", nullptr));
        penLabel->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class StylusPageWidget: public Ui_StylusPageWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // STYLUSPAGEWIDGET_H

