/****************************************************************************
** Meta object code from reading C++ file 'globalactions.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../wacomtablet-6.7.3/src/common/globalactions.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'globalactions.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Wacom13GlobalActionsE_t {};
} // unnamed namespace

template <> constexpr inline auto Wacom::GlobalActions::qt_create_metaobjectdata<qt_meta_tag_ZN5Wacom13GlobalActionsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Wacom::GlobalActions",
        "toggleTouchTriggered",
        "",
        "toggleStylusTriggered",
        "toggleScreenMapTriggered",
        "mapToFullScreenTriggered",
        "mapToScreen1Triggered",
        "mapToScreen2Triggered",
        "nextProfileTriggered",
        "previousProfileTriggered"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'toggleTouchTriggered'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'toggleStylusTriggered'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'toggleScreenMapTriggered'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mapToFullScreenTriggered'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mapToScreen1Triggered'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mapToScreen2Triggered'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nextProfileTriggered'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'previousProfileTriggered'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GlobalActions, qt_meta_tag_ZN5Wacom13GlobalActionsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Wacom::GlobalActions::staticMetaObject = { {
    QMetaObject::SuperData::link<KActionCollection::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Wacom13GlobalActionsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Wacom13GlobalActionsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Wacom13GlobalActionsE_t>.metaTypes,
    nullptr
} };

void Wacom::GlobalActions::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GlobalActions *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->toggleTouchTriggered(); break;
        case 1: _t->toggleStylusTriggered(); break;
        case 2: _t->toggleScreenMapTriggered(); break;
        case 3: _t->mapToFullScreenTriggered(); break;
        case 4: _t->mapToScreen1Triggered(); break;
        case 5: _t->mapToScreen2Triggered(); break;
        case 6: _t->nextProfileTriggered(); break;
        case 7: _t->previousProfileTriggered(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GlobalActions::*)()>(_a, &GlobalActions::toggleTouchTriggered, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalActions::*)()>(_a, &GlobalActions::toggleStylusTriggered, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalActions::*)()>(_a, &GlobalActions::toggleScreenMapTriggered, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalActions::*)()>(_a, &GlobalActions::mapToFullScreenTriggered, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalActions::*)()>(_a, &GlobalActions::mapToScreen1Triggered, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalActions::*)()>(_a, &GlobalActions::mapToScreen2Triggered, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalActions::*)()>(_a, &GlobalActions::nextProfileTriggered, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalActions::*)()>(_a, &GlobalActions::previousProfileTriggered, 7))
            return;
    }
}

const QMetaObject *Wacom::GlobalActions::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Wacom::GlobalActions::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Wacom13GlobalActionsE_t>.strings))
        return static_cast<void*>(this);
    return KActionCollection::qt_metacast(_clname);
}

int Wacom::GlobalActions::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KActionCollection::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void Wacom::GlobalActions::toggleTouchTriggered()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Wacom::GlobalActions::toggleStylusTriggered()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Wacom::GlobalActions::toggleScreenMapTriggered()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Wacom::GlobalActions::mapToFullScreenTriggered()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Wacom::GlobalActions::mapToScreen1Triggered()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Wacom::GlobalActions::mapToScreen2Triggered()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Wacom::GlobalActions::nextProfileTriggered()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Wacom::GlobalActions::previousProfileTriggered()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
