/****************************************************************************
** Meta object code from reading C++ file 'tablethandler.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../wacomtablet-6.7.3/src/kded/tablethandler.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tablethandler.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Wacom13TabletHandlerE_t {};
} // unnamed namespace

template <> constexpr inline auto Wacom::TabletHandler::qt_create_metaobjectdata<qt_meta_tag_ZN5Wacom13TabletHandlerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Wacom::TabletHandler",
        "notify",
        "",
        "eventId",
        "title",
        "message",
        "suggestConfigure",
        "profileChanged",
        "tabletId",
        "profile",
        "tabletAdded",
        "TabletInformation",
        "info",
        "tabletRemoved",
        "onTabletAdded",
        "onTabletRemoved",
        "onScreenRotated",
        "output",
        "Qt::ScreenOrientation",
        "newScreenRotation",
        "onScreenAddedRemoved",
        "QScreen*",
        "screen",
        "onScreenGeometryChanged",
        "onTogglePenMode",
        "onToggleTouch",
        "onToggleScreenMapping",
        "onMapToFullScreen",
        "onMapToScreen1",
        "onMapToScreen2",
        "onNextProfile",
        "onPreviousProfile"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'notify'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 }, { QMetaType::QString, 5 }, { QMetaType::Bool, 6 },
        }}),
        // Signal 'profileChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::QString, 9 },
        }}),
        // Signal 'tabletAdded'
        QtMocHelpers::SignalData<void(const TabletInformation &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'tabletRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Slot 'onTabletAdded'
        QtMocHelpers::SlotData<void(const TabletInformation &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'onTabletRemoved'
        QtMocHelpers::SlotData<void(const TabletInformation &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'onScreenRotated'
        QtMocHelpers::SlotData<void(QString, const Qt::ScreenOrientation &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 }, { 0x80000000 | 18, 19 },
        }}),
        // Slot 'onScreenAddedRemoved'
        QtMocHelpers::SlotData<void(QScreen *)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'onScreenGeometryChanged'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onTogglePenMode'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onToggleTouch'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onToggleScreenMapping'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onMapToFullScreen'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onMapToScreen1'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onMapToScreen2'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onNextProfile'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onPreviousProfile'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TabletHandler, qt_meta_tag_ZN5Wacom13TabletHandlerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Wacom::TabletHandler::staticMetaObject = { {
    QMetaObject::SuperData::link<TabletHandlerInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Wacom13TabletHandlerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Wacom13TabletHandlerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Wacom13TabletHandlerE_t>.metaTypes,
    nullptr
} };

void Wacom::TabletHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TabletHandler *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->notify((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 1: _t->profileChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->tabletAdded((*reinterpret_cast<std::add_pointer_t<TabletInformation>>(_a[1]))); break;
        case 3: _t->tabletRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->onTabletAdded((*reinterpret_cast<std::add_pointer_t<TabletInformation>>(_a[1]))); break;
        case 5: _t->onTabletRemoved((*reinterpret_cast<std::add_pointer_t<TabletInformation>>(_a[1]))); break;
        case 6: _t->onScreenRotated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Qt::ScreenOrientation>>(_a[2]))); break;
        case 7: _t->onScreenAddedRemoved((*reinterpret_cast<std::add_pointer_t<QScreen*>>(_a[1]))); break;
        case 8: _t->onScreenGeometryChanged(); break;
        case 9: _t->onTogglePenMode(); break;
        case 10: _t->onToggleTouch(); break;
        case 11: _t->onToggleScreenMapping(); break;
        case 12: _t->onMapToFullScreen(); break;
        case 13: _t->onMapToScreen1(); break;
        case 14: _t->onMapToScreen2(); break;
        case 15: _t->onNextProfile(); break;
        case 16: _t->onPreviousProfile(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TabletHandler::*)(const QString & , const QString & , const QString & , bool )>(_a, &TabletHandler::notify, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabletHandler::*)(const QString & , const QString & )>(_a, &TabletHandler::profileChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabletHandler::*)(const TabletInformation & )>(_a, &TabletHandler::tabletAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabletHandler::*)(const QString & )>(_a, &TabletHandler::tabletRemoved, 3))
            return;
    }
}

const QMetaObject *Wacom::TabletHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Wacom::TabletHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Wacom13TabletHandlerE_t>.strings))
        return static_cast<void*>(this);
    return TabletHandlerInterface::qt_metacast(_clname);
}

int Wacom::TabletHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = TabletHandlerInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void Wacom::TabletHandler::notify(const QString & _t1, const QString & _t2, const QString & _t3, bool _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 1
void Wacom::TabletHandler::profileChanged(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void Wacom::TabletHandler::tabletAdded(const TabletInformation & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Wacom::TabletHandler::tabletRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
