/********************************************************************************
** Form generated from reading UI file 'touchpagewidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TOUCHPAGEWIDGET_H
#define UI_TOUCHPAGEWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kmessagewidget.h"

QT_BEGIN_NAMESPACE

class Ui_TouchPageWidget
{
public:
    QVBoxLayout *verticalLayout_9;
    KMessageWidget *gesturesWarning;
    QCheckBox *touchCheckBox;
    QHBoxLayout *touchHLayout1;
    QGroupBox *trackingModeGroupBox;
    QVBoxLayout *verticalLayout_5;
    QRadioButton *trackAbsoluteRadioButton;
    QRadioButton *trackRelativeRadioButton;
    QSpacerItem *trackingFreeSpacer;
    QGroupBox *touchMappingGroupBox;
    QVBoxLayout *verticalLayout_4;
    QPushButton *touchMappingTabletButton;
    QHBoxLayout *trackingWarningLayout;
    QLabel *trackingWarningIcon;
    QLabel *trackingWarningLabel;
    QSpacerItem *touchMappingFreeSpacer;
    QCheckBox *gesturesCheckBox;
    QHBoxLayout *touchHLayout2;
    QGroupBox *gesturesGroupBox;
    QFormLayout *formLayout;
    QLabel *scrollDistanceLabel;
    QSpinBox *scrollDistanceSpinBox;
    QLabel *zoomDistanceLabel;
    QSpinBox *zoomDistanceSpinBox;
    QLabel *tapTimeLabel;
    QSpinBox *tapTimeSpinBox;
    QLabel *scrollInversionLabel;
    QCheckBox *scrollInversionCheckBox;
    QWidget *dummyWidget;
    QSpacerItem *verticalFreeSpacer;

    void setupUi(QWidget *TouchPageWidget)
    {
        if (TouchPageWidget->objectName().isEmpty())
            TouchPageWidget->setObjectName("TouchPageWidget");
        TouchPageWidget->resize(663, 418);
        verticalLayout_9 = new QVBoxLayout(TouchPageWidget);
        verticalLayout_9->setObjectName("verticalLayout_9");
        gesturesWarning = new KMessageWidget(TouchPageWidget);
        gesturesWarning->setObjectName("gesturesWarning");
        gesturesWarning->setVisible(false);
        gesturesWarning->setCloseButtonVisible(false);
        gesturesWarning->setWordWrap(true);
        gesturesWarning->setMessageType(KMessageWidget::Warning);

        verticalLayout_9->addWidget(gesturesWarning);

        touchCheckBox = new QCheckBox(TouchPageWidget);
        touchCheckBox->setObjectName("touchCheckBox");

        verticalLayout_9->addWidget(touchCheckBox);

        touchHLayout1 = new QHBoxLayout();
        touchHLayout1->setObjectName("touchHLayout1");
        trackingModeGroupBox = new QGroupBox(TouchPageWidget);
        trackingModeGroupBox->setObjectName("trackingModeGroupBox");
        trackingModeGroupBox->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(trackingModeGroupBox->sizePolicy().hasHeightForWidth());
        trackingModeGroupBox->setSizePolicy(sizePolicy);
        verticalLayout_5 = new QVBoxLayout(trackingModeGroupBox);
        verticalLayout_5->setObjectName("verticalLayout_5");
        trackAbsoluteRadioButton = new QRadioButton(trackingModeGroupBox);
        trackAbsoluteRadioButton->setObjectName("trackAbsoluteRadioButton");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(trackAbsoluteRadioButton->sizePolicy().hasHeightForWidth());
        trackAbsoluteRadioButton->setSizePolicy(sizePolicy1);
        trackAbsoluteRadioButton->setChecked(true);

        verticalLayout_5->addWidget(trackAbsoluteRadioButton);

        trackRelativeRadioButton = new QRadioButton(trackingModeGroupBox);
        trackRelativeRadioButton->setObjectName("trackRelativeRadioButton");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(trackRelativeRadioButton->sizePolicy().hasHeightForWidth());
        trackRelativeRadioButton->setSizePolicy(sizePolicy2);

        verticalLayout_5->addWidget(trackRelativeRadioButton);

        trackingFreeSpacer = new QSpacerItem(1, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        verticalLayout_5->addItem(trackingFreeSpacer);


        touchHLayout1->addWidget(trackingModeGroupBox);

        touchMappingGroupBox = new QGroupBox(TouchPageWidget);
        touchMappingGroupBox->setObjectName("touchMappingGroupBox");
        touchMappingGroupBox->setEnabled(false);
        sizePolicy.setHeightForWidth(touchMappingGroupBox->sizePolicy().hasHeightForWidth());
        touchMappingGroupBox->setSizePolicy(sizePolicy);
        verticalLayout_4 = new QVBoxLayout(touchMappingGroupBox);
        verticalLayout_4->setObjectName("verticalLayout_4");
        touchMappingTabletButton = new QPushButton(touchMappingGroupBox);
        touchMappingTabletButton->setObjectName("touchMappingTabletButton");
        sizePolicy1.setHeightForWidth(touchMappingTabletButton->sizePolicy().hasHeightForWidth());
        touchMappingTabletButton->setSizePolicy(sizePolicy1);

        verticalLayout_4->addWidget(touchMappingTabletButton);

        trackingWarningLayout = new QHBoxLayout();
        trackingWarningLayout->setObjectName("trackingWarningLayout");
        trackingWarningIcon = new QLabel(touchMappingGroupBox);
        trackingWarningIcon->setObjectName("trackingWarningIcon");
        trackingWarningIcon->setMinimumSize(QSize(16, 16));
        trackingWarningIcon->setMaximumSize(QSize(16, 16));

        trackingWarningLayout->addWidget(trackingWarningIcon);

        trackingWarningLabel = new QLabel(touchMappingGroupBox);
        trackingWarningLabel->setObjectName("trackingWarningLabel");
        trackingWarningLabel->setWordWrap(true);

        trackingWarningLayout->addWidget(trackingWarningLabel);


        verticalLayout_4->addLayout(trackingWarningLayout);

        touchMappingFreeSpacer = new QSpacerItem(1, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        verticalLayout_4->addItem(touchMappingFreeSpacer);


        touchHLayout1->addWidget(touchMappingGroupBox);


        verticalLayout_9->addLayout(touchHLayout1);

        gesturesCheckBox = new QCheckBox(TouchPageWidget);
        gesturesCheckBox->setObjectName("gesturesCheckBox");
        gesturesCheckBox->setEnabled(false);

        verticalLayout_9->addWidget(gesturesCheckBox);

        touchHLayout2 = new QHBoxLayout();
        touchHLayout2->setObjectName("touchHLayout2");
        gesturesGroupBox = new QGroupBox(TouchPageWidget);
        gesturesGroupBox->setObjectName("gesturesGroupBox");
        gesturesGroupBox->setEnabled(false);
        sizePolicy.setHeightForWidth(gesturesGroupBox->sizePolicy().hasHeightForWidth());
        gesturesGroupBox->setSizePolicy(sizePolicy);
        formLayout = new QFormLayout(gesturesGroupBox);
        formLayout->setObjectName("formLayout");
        scrollDistanceLabel = new QLabel(gesturesGroupBox);
        scrollDistanceLabel->setObjectName("scrollDistanceLabel");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(scrollDistanceLabel->sizePolicy().hasHeightForWidth());
        scrollDistanceLabel->setSizePolicy(sizePolicy3);
        scrollDistanceLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, scrollDistanceLabel);

        scrollDistanceSpinBox = new QSpinBox(gesturesGroupBox);
        scrollDistanceSpinBox->setObjectName("scrollDistanceSpinBox");
        sizePolicy2.setHeightForWidth(scrollDistanceSpinBox->sizePolicy().hasHeightForWidth());
        scrollDistanceSpinBox->setSizePolicy(sizePolicy2);
        scrollDistanceSpinBox->setMaximum(1000);
        scrollDistanceSpinBox->setSingleStep(10);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, scrollDistanceSpinBox);

        zoomDistanceLabel = new QLabel(gesturesGroupBox);
        zoomDistanceLabel->setObjectName("zoomDistanceLabel");
        sizePolicy3.setHeightForWidth(zoomDistanceLabel->sizePolicy().hasHeightForWidth());
        zoomDistanceLabel->setSizePolicy(sizePolicy3);
        zoomDistanceLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, zoomDistanceLabel);

        zoomDistanceSpinBox = new QSpinBox(gesturesGroupBox);
        zoomDistanceSpinBox->setObjectName("zoomDistanceSpinBox");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(zoomDistanceSpinBox->sizePolicy().hasHeightForWidth());
        zoomDistanceSpinBox->setSizePolicy(sizePolicy4);
        zoomDistanceSpinBox->setMaximum(1000);
        zoomDistanceSpinBox->setSingleStep(10);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, zoomDistanceSpinBox);

        tapTimeLabel = new QLabel(gesturesGroupBox);
        tapTimeLabel->setObjectName("tapTimeLabel");
        sizePolicy3.setHeightForWidth(tapTimeLabel->sizePolicy().hasHeightForWidth());
        tapTimeLabel->setSizePolicy(sizePolicy3);
        tapTimeLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, tapTimeLabel);

        tapTimeSpinBox = new QSpinBox(gesturesGroupBox);
        tapTimeSpinBox->setObjectName("tapTimeSpinBox");
        tapTimeSpinBox->setMaximum(1000);
        tapTimeSpinBox->setSingleStep(10);

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, tapTimeSpinBox);

        scrollInversionLabel = new QLabel(gesturesGroupBox);
        scrollInversionLabel->setObjectName("scrollInversionLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, scrollInversionLabel);

        scrollInversionCheckBox = new QCheckBox(gesturesGroupBox);
        scrollInversionCheckBox->setObjectName("scrollInversionCheckBox");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, scrollInversionCheckBox);


        touchHLayout2->addWidget(gesturesGroupBox);

        dummyWidget = new QWidget(TouchPageWidget);
        dummyWidget->setObjectName("dummyWidget");
        sizePolicy.setHeightForWidth(dummyWidget->sizePolicy().hasHeightForWidth());
        dummyWidget->setSizePolicy(sizePolicy);

        touchHLayout2->addWidget(dummyWidget);


        verticalLayout_9->addLayout(touchHLayout2);

        verticalFreeSpacer = new QSpacerItem(1, 1, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_9->addItem(verticalFreeSpacer);


        retranslateUi(TouchPageWidget);
        QObject::connect(touchCheckBox, SIGNAL(stateChanged(int)), TouchPageWidget, SLOT(onTouchModeChanged(int)));
        QObject::connect(trackAbsoluteRadioButton, SIGNAL(toggled(bool)), TouchPageWidget, SLOT(onTrackingModeAbsolute(bool)));
        QObject::connect(trackRelativeRadioButton, SIGNAL(toggled(bool)), TouchPageWidget, SLOT(onTrackingModeRelative(bool)));
        QObject::connect(touchMappingTabletButton, SIGNAL(clicked()), TouchPageWidget, SLOT(onTabletMappingClicked()));
        QObject::connect(scrollDistanceSpinBox, SIGNAL(valueChanged(int)), TouchPageWidget, SLOT(onProfileChanged()));
        QObject::connect(zoomDistanceSpinBox, SIGNAL(valueChanged(int)), TouchPageWidget, SLOT(onProfileChanged()));
        QObject::connect(tapTimeSpinBox, SIGNAL(valueChanged(int)), TouchPageWidget, SLOT(onProfileChanged()));
        QObject::connect(gesturesCheckBox, SIGNAL(stateChanged(int)), TouchPageWidget, SLOT(onGesturesModeChanged(int)));
        QObject::connect(scrollInversionCheckBox, SIGNAL(toggled(bool)), TouchPageWidget, SLOT(onProfileChanged()));

        QMetaObject::connectSlotsByName(TouchPageWidget);
    } // setupUi

    void retranslateUi(QWidget *TouchPageWidget)
    {
        gesturesWarning->setText(tr2i18n("Enabling gestures may break touch input using a touchscreen.", nullptr));
#if QT_CONFIG(tooltip)
        touchCheckBox->setToolTip(tr2i18n("If enabled the tablet will emit touch events.", nullptr));
#endif // QT_CONFIG(tooltip)
        touchCheckBox->setText(tr2i18n("Enable Touch", nullptr));
#if QT_CONFIG(tooltip)
        trackingModeGroupBox->setToolTip(tr2i18n("Defines how the cursor movement mode will be used.", nullptr));
#endif // QT_CONFIG(tooltip)
        trackingModeGroupBox->setTitle(tr2i18n("Touch Tracking Mode", nullptr));
        trackAbsoluteRadioButton->setText(tr2i18n("&Map to Screen (Absolute Mode)", nullptr));
        trackRelativeRadioButton->setText(tr2i18n("Map &to Cursor (Relative Mode)", nullptr));
        touchMappingGroupBox->setTitle(tr2i18n("Touch Mapping", nullptr));
#if QT_CONFIG(tooltip)
        touchMappingTabletButton->setToolTip(tr2i18n("Allows one to specify the tablet area for different screen selections in absolute cursor mode.", nullptr));
#endif // QT_CONFIG(tooltip)
        touchMappingTabletButton->setText(tr2i18n("Map Touch Area to Screen", nullptr));
        trackingWarningIcon->setText(QString());
        trackingWarningLabel->setText(tr2i18n("Your currently selected mapping can not be applied in relative tracking mode.", nullptr));
#if QT_CONFIG(tooltip)
        gesturesCheckBox->setToolTip(tr2i18n("If enabled the touch events can recognize gestures.", nullptr));
#endif // QT_CONFIG(tooltip)
        gesturesCheckBox->setText(tr2i18n("Enable Gestures", nullptr));
        gesturesGroupBox->setTitle(tr2i18n("Gestures", nullptr));
#if QT_CONFIG(tooltip)
        scrollDistanceLabel->setToolTip(tr2i18n("Minimum motion before sending a scroll gesture.", nullptr));
#endif // QT_CONFIG(tooltip)
        scrollDistanceLabel->setText(tr2i18n("Scroll Distance", nullptr));
#if QT_CONFIG(tooltip)
        scrollDistanceSpinBox->setToolTip(tr2i18n("The minimum motion in tablet units before sending a scroll event.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        zoomDistanceLabel->setToolTip(tr2i18n("Minimum distance for a zoom gesture is recognized.", nullptr));
#endif // QT_CONFIG(tooltip)
        zoomDistanceLabel->setText(tr2i18n("Zoom Distance", nullptr));
#if QT_CONFIG(tooltip)
        zoomDistanceSpinBox->setToolTip(tr2i18n("The minimum distance in tablet units for a zoom gesture to be recognized.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        tapTimeLabel->setToolTip(tr2i18n("Minimum time between taps for a right click.", nullptr));
#endif // QT_CONFIG(tooltip)
        tapTimeLabel->setText(tr2i18n("Tap Time", nullptr));
#if QT_CONFIG(tooltip)
        tapTimeSpinBox->setToolTip(tr2i18n("The minimum time in milliseconds between taps to trigger a right click.", nullptr));
#endif // QT_CONFIG(tooltip)
        scrollInversionLabel->setText(tr2i18n("Invert Scroll Direction", nullptr));
#if QT_CONFIG(tooltip)
        scrollInversionCheckBox->setToolTip(tr2i18n("If selected, the scroll direction for the scroll gesture is inverted.", nullptr));
#endif // QT_CONFIG(tooltip)
        scrollInversionCheckBox->setText(QString());
        (void)TouchPageWidget;
    } // retranslateUi

};

namespace Ui {
    class TouchPageWidget: public Ui_TouchPageWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TOUCHPAGEWIDGET_H

