/********************************************************************************
** Form generated from reading UI file 'buttonactionselectionwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BUTTONACTIONSELECTIONWIDGET_H
#define UI_BUTTONACTIONSELECTIONWIDGET_H

#include <QtCore/QLocale>
#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "buttonactiondisplaywidget.h"
#include "keysequenceinputwidget.h"

QT_BEGIN_NAMESPACE

class Ui_ButtonActionSelectionWidget
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    QHBoxLayout *modifierLayout;
    QCheckBox *ctrlModifierCheckBox;
    QSpacerItem *modifierSpacer2;
    QCheckBox *altModifierCheckBox;
    QSpacerItem *modifierSpacer3;
    QCheckBox *metaModifierCheckBox;
    QSpacerItem *modifierSpacer4;
    QCheckBox *shiftModifierCheckBox;
    QPushButton *modifierClearButton;
    QSpacerItem *dummySpacer;
    Wacom::ButtonActionDisplayWidget *actionNameLineEdit;
    QLabel *mouseIconLabel;
    QHBoxLayout *mouseLayout;
    QComboBox *mouseComboBox;
    QPushButton *mouseClearButton;
    Wacom::KeySequenceInputWidget *shortcutSelectorWidget;
    QLabel *keyboardIconLabel;
    QSpacerItem *freeSpaceSpacer;

    void setupUi(QWidget *ButtonActionSelectionWidget)
    {
        if (ButtonActionSelectionWidget->objectName().isEmpty())
            ButtonActionSelectionWidget->setObjectName("ButtonActionSelectionWidget");
        ButtonActionSelectionWidget->resize(564, 282);
        ButtonActionSelectionWidget->setLocale(QLocale(QLocale::English, QLocale::UnitedStates));
        verticalLayout = new QVBoxLayout(ButtonActionSelectionWidget);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout->setObjectName("verticalLayout");
        groupBox = new QGroupBox(ButtonActionSelectionWidget);
        groupBox->setObjectName("groupBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy);
        groupBox->setLocale(QLocale(QLocale::English, QLocale::UnitedStates));
        groupBox->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setObjectName("gridLayout_2");
        modifierLayout = new QHBoxLayout();
        modifierLayout->setObjectName("modifierLayout");
        ctrlModifierCheckBox = new QCheckBox(groupBox);
        ctrlModifierCheckBox->setObjectName("ctrlModifierCheckBox");

        modifierLayout->addWidget(ctrlModifierCheckBox);

        modifierSpacer2 = new QSpacerItem(10, 1, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        modifierLayout->addItem(modifierSpacer2);

        altModifierCheckBox = new QCheckBox(groupBox);
        altModifierCheckBox->setObjectName("altModifierCheckBox");

        modifierLayout->addWidget(altModifierCheckBox);

        modifierSpacer3 = new QSpacerItem(10, 1, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        modifierLayout->addItem(modifierSpacer3);

        metaModifierCheckBox = new QCheckBox(groupBox);
        metaModifierCheckBox->setObjectName("metaModifierCheckBox");

        modifierLayout->addWidget(metaModifierCheckBox);

        modifierSpacer4 = new QSpacerItem(10, 1, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        modifierLayout->addItem(modifierSpacer4);

        shiftModifierCheckBox = new QCheckBox(groupBox);
        shiftModifierCheckBox->setObjectName("shiftModifierCheckBox");

        modifierLayout->addWidget(shiftModifierCheckBox);

        modifierClearButton = new QPushButton(groupBox);
        modifierClearButton->setObjectName("modifierClearButton");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(modifierClearButton->sizePolicy().hasHeightForWidth());
        modifierClearButton->setSizePolicy(sizePolicy1);
        modifierClearButton->setMaximumSize(QSize(25, 16777215));

        modifierLayout->addWidget(modifierClearButton);


        gridLayout_2->addLayout(modifierLayout, 2, 1, 1, 1);

        dummySpacer = new QSpacerItem(64, 1, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(dummySpacer, 5, 0, 1, 1);

        actionNameLineEdit = new Wacom::ButtonActionDisplayWidget(groupBox);
        actionNameLineEdit->setObjectName("actionNameLineEdit");
        actionNameLineEdit->setReadOnly(true);

        gridLayout_2->addWidget(actionNameLineEdit, 5, 1, 1, 1);

        mouseIconLabel = new QLabel(groupBox);
        mouseIconLabel->setObjectName("mouseIconLabel");
        mouseIconLabel->setAlignment(Qt::AlignCenter);

        gridLayout_2->addWidget(mouseIconLabel, 0, 0, 1, 1);

        mouseLayout = new QHBoxLayout();
        mouseLayout->setObjectName("mouseLayout");
        mouseComboBox = new QComboBox(groupBox);
        mouseComboBox->setObjectName("mouseComboBox");

        mouseLayout->addWidget(mouseComboBox);

        mouseClearButton = new QPushButton(groupBox);
        mouseClearButton->setObjectName("mouseClearButton");
        sizePolicy1.setHeightForWidth(mouseClearButton->sizePolicy().hasHeightForWidth());
        mouseClearButton->setSizePolicy(sizePolicy1);
        mouseClearButton->setMaximumSize(QSize(25, 16777215));

        mouseLayout->addWidget(mouseClearButton);


        gridLayout_2->addLayout(mouseLayout, 0, 1, 1, 1);

        shortcutSelectorWidget = new Wacom::KeySequenceInputWidget(groupBox);
        shortcutSelectorWidget->setObjectName("shortcutSelectorWidget");

        gridLayout_2->addWidget(shortcutSelectorWidget, 4, 1, 1, 1);

        keyboardIconLabel = new QLabel(groupBox);
        keyboardIconLabel->setObjectName("keyboardIconLabel");
        sizePolicy.setHeightForWidth(keyboardIconLabel->sizePolicy().hasHeightForWidth());
        keyboardIconLabel->setSizePolicy(sizePolicy);
        keyboardIconLabel->setAlignment(Qt::AlignHCenter|Qt::AlignTop);

        gridLayout_2->addWidget(keyboardIconLabel, 2, 0, 3, 1);


        verticalLayout->addWidget(groupBox);

        freeSpaceSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(freeSpaceSpacer);


        retranslateUi(ButtonActionSelectionWidget);

        QMetaObject::connectSlotsByName(ButtonActionSelectionWidget);
    } // setupUi

    void retranslateUi(QWidget *ButtonActionSelectionWidget)
    {
        ButtonActionSelectionWidget->setWindowTitle(tr2i18n("Select Key Function", nullptr));
        groupBox->setTitle(tr2i18n("Select Button Action", nullptr));
        ctrlModifierCheckBox->setText(tr2i18n("Ctrl", nullptr));
        altModifierCheckBox->setText(tr2i18n("Alt", nullptr));
        metaModifierCheckBox->setText(tr2i18n("Meta", nullptr));
        shiftModifierCheckBox->setText(tr2i18n("Shift", nullptr));
        actionNameLineEdit->setPlaceholderText(tr2i18n("Please select an action.", nullptr));
        mouseIconLabel->setText(QString());
        keyboardIconLabel->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class ButtonActionSelectionWidget: public Ui_ButtonActionSelectionWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BUTTONACTIONSELECTIONWIDGET_H

