/****************************************************************************
** Meta object code from reading C++ file 'wacomadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "wacomadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'wacomadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12WacomAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto WacomAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN12WacomAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WacomAdaptor",
        "D-Bus Interface",
        "org.kde.Wacom",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.Wacom\">\n    <method name=\"getTablet"
        "List\">\n      <arg direction=\"out\" type=\"as\"/>\n    </method>"
        "\n    <method name=\"getDeviceList\">\n      <arg direction=\"in\""
        " type=\"s\" name=\"tabletId\"/>\n      <arg direction=\"out\" type"
        "=\"as\"/>\n    </method>\n    <method name=\"getDeviceName\">\n   "
        "   <arg direction=\"in\" type=\"s\" name=\"tabletId\"/>\n      <ar"
        "g direction=\"in\" type=\"s\" name=\"device\"/>\n      <arg direct"
        "ion=\"out\" type=\"s\"/>\n    </method>\n    <method name=\"getTou"
        "chSensorId\">\n      <arg direction=\"in\" type=\"s\" name=\"table"
        "tId\"/>\n      <arg direction=\"out\" type=\"s\"/>\n    </method>\n"
        "    <method name=\"getInformation\">\n      <arg direction=\"in\" "
        "type=\"s\" name=\"tabletId\"/>\n      <arg direction=\"in\" type=\""
        "s\" name=\"info\"/>\n      <arg direction=\"out\" type=\"s\"/>\n  "
        "  </method>\n    <method name=\"getProfile\">\n      <arg directio"
        "n=\"in\" type=\"s\" name=\"tabletId\"/>\n      <arg direction=\"ou"
        "t\" type=\"s\"/>\n    </method>\n    <method name=\"getProperty\">"
        "\n      <arg direction=\"in\" type=\"s\" name=\"tabletId\"/>\n    "
        "  <arg direction=\"in\" type=\"s\" name=\"device\"/>\n      <arg d"
        "irection=\"in\" type=\"s\" name=\"param\"/>\n      <arg direction="
        "\"out\" type=\"s\"/>\n    </method>\n    <method name=\"hasPadButt"
        "ons\">\n      <arg direction=\"in\" type=\"s\" name=\"tabletId\"/>"
        "\n      <arg direction=\"out\" type=\"b\"/>\n    </method>\n    <m"
        "ethod name=\"isTouchSensor\">\n      <arg direction=\"in\" type=\""
        "s\" name=\"tabletId\"/>\n      <arg direction=\"out\" type=\"b\"/>"
        "\n    </method>\n    <method name=\"isAvailable\">\n      <arg dir"
        "ection=\"in\" type=\"s\" name=\"tabletId\"/>\n      <arg direction"
        "=\"out\" type=\"b\"/>\n    </method>\n    <method name=\"listProfi"
        "les\">\n      <arg direction=\"in\" type=\"s\" name=\"tabletId\"/>"
        "\n      <arg direction=\"out\" type=\"as\"/>\n    </method>\n    <"
        "method name=\"setProfile\">\n      <arg direction=\"in\" type=\"s\""
        " name=\"tabletId\"/>\n      <arg direction=\"in\" type=\"s\" name="
        "\"profile\"/>\n    </method>\n    <method name=\"setProperty\">\n "
        "     <arg direction=\"in\" type=\"s\" name=\"tabletId\"/>\n      <"
        "arg direction=\"in\" type=\"s\" name=\"device\"/>\n      <arg dire"
        "ction=\"in\" type=\"s\" name=\"param\"/>\n      <arg direction=\"i"
        "n\" type=\"s\" name=\"value\"/>\n    </method>\n    <method name=\""
        "getProfileRotationList\">\n      <arg direction=\"in\" type=\"s\" "
        "name=\"tabletId\"/>\n      <arg direction=\"out\" type=\"as\"/>\n "
        "   </method>\n    <method name=\"setProfileRotationList\">\n      "
        "<arg direction=\"in\" type=\"s\" name=\"tabletId\"/>\n      <arg d"
        "irection=\"in\" type=\"as\"/>\n    </method>\n    <signal name=\"p"
        "rofileChanged\">\n      <arg direction=\"out\" type=\"s\" name=\"t"
        "abletId\"/>\n      <arg direction=\"out\" type=\"s\" name=\"profil"
        "e\"/>\n    </signal>\n    <signal name=\"tabletAdded\">\n      <ar"
        "g direction=\"out\" type=\"s\" name=\"tabletId\"/>\n    </signal>\n"
        "    <signal name=\"tabletRemoved\">\n      <arg direction=\"out\" "
        "type=\"s\" name=\"tabletId\"/>\n    </signal>\n  </interface>\n",
        "profileChanged",
        "",
        "tabletId",
        "profile",
        "tabletAdded",
        "tabletRemoved",
        "getDeviceList",
        "getDeviceName",
        "device",
        "getInformation",
        "info",
        "getProfile",
        "getProfileRotationList",
        "getProperty",
        "param",
        "getTabletList",
        "getTouchSensorId",
        "hasPadButtons",
        "isAvailable",
        "isTouchSensor",
        "listProfiles",
        "setProfile",
        "setProfileRotationList",
        "in1",
        "setProperty",
        "value"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'profileChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'tabletAdded'
        QtMocHelpers::SignalData<void(const QString &)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'tabletRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'getDeviceList'
        QtMocHelpers::SlotData<QStringList(const QString &)>(11, 6, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'getDeviceName'
        QtMocHelpers::SlotData<QString(const QString &, const QString &)>(12, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 13 },
        }}),
        // Slot 'getInformation'
        QtMocHelpers::SlotData<QString(const QString &, const QString &)>(14, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 15 },
        }}),
        // Slot 'getProfile'
        QtMocHelpers::SlotData<QString(const QString &)>(16, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'getProfileRotationList'
        QtMocHelpers::SlotData<QStringList(const QString &)>(17, 6, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'getProperty'
        QtMocHelpers::SlotData<QString(const QString &, const QString &, const QString &)>(18, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 13 }, { QMetaType::QString, 19 },
        }}),
        // Slot 'getTabletList'
        QtMocHelpers::SlotData<QStringList()>(20, 6, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'getTouchSensorId'
        QtMocHelpers::SlotData<QString(const QString &)>(21, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'hasPadButtons'
        QtMocHelpers::SlotData<bool(const QString &)>(22, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'isAvailable'
        QtMocHelpers::SlotData<bool(const QString &)>(23, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'isTouchSensor'
        QtMocHelpers::SlotData<bool(const QString &)>(24, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'listProfiles'
        QtMocHelpers::SlotData<QStringList(const QString &)>(25, 6, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'setProfile'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(26, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 },
        }}),
        // Slot 'setProfileRotationList'
        QtMocHelpers::SlotData<void(const QString &, const QStringList &)>(27, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QStringList, 28 },
        }}),
        // Slot 'setProperty'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &, const QString &)>(29, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 13 }, { QMetaType::QString, 19 }, { QMetaType::QString, 30 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<WacomAdaptor, qt_meta_tag_ZN12WacomAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject WacomAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12WacomAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12WacomAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12WacomAdaptorE_t>.metaTypes,
    nullptr
} };

void WacomAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WacomAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->profileChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->tabletAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->tabletRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: { QStringList _r = _t->getDeviceList((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 4: { QString _r = _t->getDeviceName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { QString _r = _t->getInformation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 6: { QString _r = _t->getProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 7: { QStringList _r = _t->getProfileRotationList((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 8: { QString _r = _t->getProperty((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 9: { QStringList _r = _t->getTabletList();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 10: { QString _r = _t->getTouchSensorId((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->hasPadButtons((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->isAvailable((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { bool _r = _t->isTouchSensor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: { QStringList _r = _t->listProfiles((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->setProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 16: _t->setProfileRotationList((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 17: _t->setProperty((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WacomAdaptor::*)(const QString & , const QString & )>(_a, &WacomAdaptor::profileChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WacomAdaptor::*)(const QString & )>(_a, &WacomAdaptor::tabletAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (WacomAdaptor::*)(const QString & )>(_a, &WacomAdaptor::tabletRemoved, 2))
            return;
    }
}

const QMetaObject *WacomAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WacomAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12WacomAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int WacomAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void WacomAdaptor::profileChanged(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void WacomAdaptor::tabletAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void WacomAdaptor::tabletRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
