/********************************************************************************
** Form generated from reading UI file 'kcmwacomtabletwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KCMWACOMTABLETWIDGET_H
#define UI_KCMWACOMTABLETWIDGET_H

#include <QtCore/QLocale>
#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kanimatedbutton.h"

QT_BEGIN_NAMESPACE

class Ui_KCMWacomTabletWidget
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *tabletListLabel;
    QComboBox *tabletListSelector;
    QLabel *profileLabel;
    QHBoxLayout *profileLayout;
    QComboBox *profileSelector;
    KAnimatedButton *addProfileButton;
    KAnimatedButton *delProfileButton;
    QTabWidget *deviceTabWidget;

    void setupUi(QWidget *KCMWacomTabletWidget)
    {
        if (KCMWacomTabletWidget->objectName().isEmpty())
            KCMWacomTabletWidget->setObjectName("KCMWacomTabletWidget");
        KCMWacomTabletWidget->resize(646, 522);
        KCMWacomTabletWidget->setLocale(QLocale(QLocale::English, QLocale::UnitedKingdom));
        verticalLayout = new QVBoxLayout(KCMWacomTabletWidget);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        tabletListLabel = new QLabel(KCMWacomTabletWidget);
        tabletListLabel->setObjectName("tabletListLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, tabletListLabel);

        tabletListSelector = new QComboBox(KCMWacomTabletWidget);
        tabletListSelector->setObjectName("tabletListSelector");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(tabletListSelector->sizePolicy().hasHeightForWidth());
        tabletListSelector->setSizePolicy(sizePolicy);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, tabletListSelector);

        profileLabel = new QLabel(KCMWacomTabletWidget);
        profileLabel->setObjectName("profileLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, profileLabel);

        profileLayout = new QHBoxLayout();
        profileLayout->setObjectName("profileLayout");
        profileSelector = new QComboBox(KCMWacomTabletWidget);
        profileSelector->setObjectName("profileSelector");
        sizePolicy.setHeightForWidth(profileSelector->sizePolicy().hasHeightForWidth());
        profileSelector->setSizePolicy(sizePolicy);

        profileLayout->addWidget(profileSelector);

        addProfileButton = new KAnimatedButton(KCMWacomTabletWidget);
        addProfileButton->setObjectName("addProfileButton");
        addProfileButton->setToolButtonStyle(Qt::ToolButtonIconOnly);
        addProfileButton->setProperty("animationPath", QVariant(QString::fromUtf8("document-new")));

        profileLayout->addWidget(addProfileButton);

        delProfileButton = new KAnimatedButton(KCMWacomTabletWidget);
        delProfileButton->setObjectName("delProfileButton");
        delProfileButton->setProperty("animationPath", QVariant(QString::fromUtf8("edit-delete-page")));

        profileLayout->addWidget(delProfileButton);


        formLayout->setLayout(1, QFormLayout::ItemRole::FieldRole, profileLayout);


        verticalLayout->addLayout(formLayout);

        deviceTabWidget = new QTabWidget(KCMWacomTabletWidget);
        deviceTabWidget->setObjectName("deviceTabWidget");
        deviceTabWidget->setDocumentMode(true);

        verticalLayout->addWidget(deviceTabWidget);

#if QT_CONFIG(shortcut)
        tabletListLabel->setBuddy(tabletListSelector);
        profileLabel->setBuddy(profileSelector);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(profileSelector, addProfileButton);
        QWidget::setTabOrder(addProfileButton, delProfileButton);
        QWidget::setTabOrder(delProfileButton, deviceTabWidget);

        retranslateUi(KCMWacomTabletWidget);

        QMetaObject::connectSlotsByName(KCMWacomTabletWidget);
    } // setupUi

    void retranslateUi(QWidget *KCMWacomTabletWidget)
    {
        KCMWacomTabletWidget->setWindowTitle(tr2i18n("Graphic Tablet Settings", nullptr));
        tabletListLabel->setText(tr2i18n("&Select Tablet:", nullptr));
        profileLabel->setText(tr2i18n("Select &Profile:", nullptr));
#if QT_CONFIG(tooltip)
        addProfileButton->setToolTip(tr2i18n("Creates a new default profile", nullptr));
#endif // QT_CONFIG(tooltip)
        addProfileButton->setText(QString());
#if QT_CONFIG(tooltip)
        delProfileButton->setToolTip(tr2i18n("Deletes the current profile", nullptr));
#endif // QT_CONFIG(tooltip)
    } // retranslateUi

};

namespace Ui {
    class KCMWacomTabletWidget: public Ui_KCMWacomTabletWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KCMWACOMTABLETWIDGET_H

