/****************************************************************************
** Meta object code from reading C++ file 'wacominterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "wacominterface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'wacominterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20OrgKdeWacomInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgKdeWacomInterface::qt_create_metaobjectdata<qt_meta_tag_ZN20OrgKdeWacomInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgKdeWacomInterface",
        "profileChanged",
        "",
        "tabletId",
        "profile",
        "tabletAdded",
        "tabletRemoved",
        "getDeviceList",
        "QDBusPendingReply<QStringList>",
        "getDeviceName",
        "QDBusPendingReply<QString>",
        "device",
        "getInformation",
        "info",
        "getProfile",
        "getProfileRotationList",
        "getProperty",
        "param",
        "getTabletList",
        "getTouchSensorId",
        "hasPadButtons",
        "QDBusPendingReply<bool>",
        "isAvailable",
        "isTouchSensor",
        "listProfiles",
        "setProfile",
        "QDBusPendingReply<>",
        "setProfileRotationList",
        "in1",
        "setProperty",
        "value"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'profileChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'tabletAdded'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'tabletRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'getDeviceList'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>(const QString &)>(7, 2, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'getDeviceName'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &, const QString &)>(9, 2, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 11 },
        }}),
        // Slot 'getInformation'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &, const QString &)>(12, 2, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 13 },
        }}),
        // Slot 'getProfile'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(14, 2, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'getProfileRotationList'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>(const QString &)>(15, 2, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'getProperty'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &, const QString &, const QString &)>(16, 2, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 11 }, { QMetaType::QString, 17 },
        }}),
        // Slot 'getTabletList'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(18, 2, QMC::AccessPublic, 0x80000000 | 8),
        // Slot 'getTouchSensorId'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(19, 2, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'hasPadButtons'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &)>(20, 2, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'isAvailable'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &)>(22, 2, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'isTouchSensor'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &)>(23, 2, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'listProfiles'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>(const QString &)>(24, 2, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'setProfile'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(25, 2, QMC::AccessPublic, 0x80000000 | 26, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Slot 'setProfileRotationList'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QStringList &)>(27, 2, QMC::AccessPublic, 0x80000000 | 26, {{
            { QMetaType::QString, 3 }, { QMetaType::QStringList, 28 },
        }}),
        // Slot 'setProperty'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &, const QString &, const QString &)>(29, 2, QMC::AccessPublic, 0x80000000 | 26, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 11 }, { QMetaType::QString, 17 }, { QMetaType::QString, 30 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgKdeWacomInterface, qt_meta_tag_ZN20OrgKdeWacomInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgKdeWacomInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20OrgKdeWacomInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20OrgKdeWacomInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20OrgKdeWacomInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgKdeWacomInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgKdeWacomInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->profileChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->tabletAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->tabletRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: { QDBusPendingReply<QStringList> _r = _t->getDeviceList((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<QString> _r = _t->getDeviceName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<QString> _r = _t->getInformation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<QString> _r = _t->getProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<QStringList> _r = _t->getProfileRotationList((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<QString> _r = _t->getProperty((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<QStringList> _r = _t->getTabletList();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<QString> _r = _t->getTouchSensorId((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<bool> _r = _t->hasPadButtons((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<bool> _r = _t->isAvailable((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<bool> _r = _t->isTouchSensor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<QStringList> _r = _t->listProfiles((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusPendingReply<> _r = _t->setProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusPendingReply<> _r = _t->setProfileRotationList((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<> _r = _t->setProperty((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgKdeWacomInterface::*)(const QString & , const QString & )>(_a, &OrgKdeWacomInterface::profileChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeWacomInterface::*)(const QString & )>(_a, &OrgKdeWacomInterface::tabletAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeWacomInterface::*)(const QString & )>(_a, &OrgKdeWacomInterface::tabletRemoved, 2))
            return;
    }
}

const QMetaObject *OrgKdeWacomInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgKdeWacomInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20OrgKdeWacomInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgKdeWacomInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void OrgKdeWacomInterface::profileChanged(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void OrgKdeWacomInterface::tabletAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void OrgKdeWacomInterface::tabletRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
