/********************************************************************************
** Form generated from reading UI file 'errorwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ERRORWIDGET_H
#define UI_ERRORWIDGET_H

#include <QtCore/QLocale>
#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCommandLinkButton>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ErrorWidget
{
public:
    QHBoxLayout *horizontalLayout;
    QVBoxLayout *imageLayout;
    QLabel *errorImage;
    QSpacerItem *imageFreeSpacer;
    QVBoxLayout *textLayout;
    QLabel *errorTitle;
    QLabel *errorText;
    QCommandLinkButton *buttonRunTabletFinder;
    QSpacerItem *errorFreeSpacer;

    void setupUi(QWidget *ErrorWidget)
    {
        if (ErrorWidget->objectName().isEmpty())
            ErrorWidget->setObjectName("ErrorWidget");
        ErrorWidget->resize(869, 163);
        ErrorWidget->setLocale(QLocale(QLocale::English, QLocale::UnitedKingdom));
        horizontalLayout = new QHBoxLayout(ErrorWidget);
        horizontalLayout->setObjectName("horizontalLayout");
        imageLayout = new QVBoxLayout();
        imageLayout->setObjectName("imageLayout");
        errorImage = new QLabel(ErrorWidget);
        errorImage->setObjectName("errorImage");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(errorImage->sizePolicy().hasHeightForWidth());
        errorImage->setSizePolicy(sizePolicy);
        errorImage->setMinimumSize(QSize(48, 48));
        errorImage->setMaximumSize(QSize(48, 48));

        imageLayout->addWidget(errorImage);

        imageFreeSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        imageLayout->addItem(imageFreeSpacer);


        horizontalLayout->addLayout(imageLayout);

        textLayout = new QVBoxLayout();
        textLayout->setObjectName("textLayout");
        errorTitle = new QLabel(ErrorWidget);
        errorTitle->setObjectName("errorTitle");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(errorTitle->sizePolicy().hasHeightForWidth());
        errorTitle->setSizePolicy(sizePolicy1);
        QFont font;
        font.setPointSize(14);
        font.setBold(true);
        errorTitle->setFont(font);
        errorTitle->setStyleSheet(QString::fromUtf8("font-weight: bold;\n"
"font-size: 120%;"));

        textLayout->addWidget(errorTitle);

        errorText = new QLabel(ErrorWidget);
        errorText->setObjectName("errorText");
        sizePolicy1.setHeightForWidth(errorText->sizePolicy().hasHeightForWidth());
        errorText->setSizePolicy(sizePolicy1);
        errorText->setWordWrap(true);

        textLayout->addWidget(errorText);

        buttonRunTabletFinder = new QCommandLinkButton(ErrorWidget);
        buttonRunTabletFinder->setObjectName("buttonRunTabletFinder");

        textLayout->addWidget(buttonRunTabletFinder);

        errorFreeSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        textLayout->addItem(errorFreeSpacer);


        horizontalLayout->addLayout(textLayout);


        retranslateUi(ErrorWidget);

        QMetaObject::connectSlotsByName(ErrorWidget);
    } // setupUi

    void retranslateUi(QWidget *ErrorWidget)
    {
        ErrorWidget->setWindowTitle(tr2i18n("No Tablet Found", nullptr));
        errorImage->setText(QString());
        errorTitle->setText(QString());
        errorText->setText(QString());
        buttonRunTabletFinder->setText(tr2i18n("Manually register a tablet device", nullptr));
        buttonRunTabletFinder->setDescription(tr2i18n("This will open another window, prompting you to describe your tablet device. After you're done, please restart your desktop session.", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ErrorWidget: public Ui_ErrorWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ERRORWIDGET_H

