/********************************************************************************
** Form generated from reading UI file 'buttonpagewidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BUTTONPAGEWIDGET_H
#define UI_BUTTONPAGEWIDGET_H

#include <QtCore/QLocale>
#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "buttonactionselectorwidget.h"

QT_BEGIN_NAMESPACE

class Ui_ButtonPageWidget
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *buttonGroupBox;
    QHBoxLayout *horizontalLayout;
    QFormLayout *leftButtonLayout;
    QLabel *button1Label;
    QLabel *button2Label;
    QLabel *button3Label;
    QLabel *button4Label;
    QLabel *button5Label;
    QLabel *button6Label;
    QLabel *button7Label;
    QLabel *button8Label;
    QLabel *button9Label;
    QSpacerItem *leftButtonHSpacer;
    Wacom::ButtonActionSelectorWidget *button1ActionSelector;
    Wacom::ButtonActionSelectorWidget *button2ActionSelector;
    Wacom::ButtonActionSelectorWidget *button3ActionSelector;
    Wacom::ButtonActionSelectorWidget *button4ActionSelector;
    Wacom::ButtonActionSelectorWidget *button5ActionSelector;
    Wacom::ButtonActionSelectorWidget *button6ActionSelector;
    Wacom::ButtonActionSelectorWidget *button7ActionSelector;
    Wacom::ButtonActionSelectorWidget *button8ActionSelector;
    Wacom::ButtonActionSelectorWidget *button9ActionSelector;
    QVBoxLayout *padImageLayout;
    QLabel *padImage;
    QSpacerItem *padImageVSpacer;
    QFormLayout *rightButtonLayout;
    QLabel *button10Label;
    QLabel *button11Label;
    QLabel *button12Label;
    QLabel *button13Label;
    QLabel *button14Label;
    QLabel *button15Label;
    QLabel *button16Label;
    QLabel *button17Label;
    QLabel *button18Label;
    QSpacerItem *rightButtonHSpacer;
    Wacom::ButtonActionSelectorWidget *button10ActionSelector;
    Wacom::ButtonActionSelectorWidget *button11ActionSelector;
    Wacom::ButtonActionSelectorWidget *button12ActionSelector;
    Wacom::ButtonActionSelectorWidget *button13ActionSelector;
    Wacom::ButtonActionSelectorWidget *button14ActionSelector;
    Wacom::ButtonActionSelectorWidget *button15ActionSelector;
    Wacom::ButtonActionSelectorWidget *button16ActionSelector;
    Wacom::ButtonActionSelectorWidget *button17ActionSelector;
    Wacom::ButtonActionSelectorWidget *button18ActionSelector;
    QGroupBox *touchStripGroupBox;
    QHBoxLayout *horizontalLayout_2;
    QWidget *leftStripWidget;
    QFormLayout *formLayout;
    QLabel *leftStripUpLabel;
    Wacom::ButtonActionSelectorWidget *leftStripUpSelector;
    QLabel *leftStripDownLabel;
    Wacom::ButtonActionSelectorWidget *leftStripDownSelector;
    QSpacerItem *stripHSpacer;
    QWidget *rightStripWidget;
    QFormLayout *formLayout_2;
    QLabel *rightStripUpLabel;
    Wacom::ButtonActionSelectorWidget *rightStripUpSelector;
    QLabel *rightStripDownLabel;
    Wacom::ButtonActionSelectorWidget *rightStripDownSelector;
    QGroupBox *touchRingGroupBox;
    QHBoxLayout *horizontalLayout_3;
    QFormLayout *leftRingLayout;
    QLabel *ringUpLabel;
    Wacom::ButtonActionSelectorWidget *ringUpSelector;
    QSpacerItem *ringHSpacer;
    QFormLayout *rightRingLayout;
    QLabel *ringDownLabel;
    Wacom::ButtonActionSelectorWidget *ringDownSelector;
    QGroupBox *wheelGroupBox;
    QHBoxLayout *horizontalLayout_4;
    QFormLayout *leftWheelLayout;
    QLabel *wheelUpLabel;
    Wacom::ButtonActionSelectorWidget *wheelUpSelector;
    QSpacerItem *wheelHSpacer;
    QFormLayout *rightWheelLayout;
    QLabel *wheelDownLabel;
    Wacom::ButtonActionSelectorWidget *wheelDownSelector;
    QSpacerItem *freeSpaceVSpacer;

    void setupUi(QWidget *ButtonPageWidget)
    {
        if (ButtonPageWidget->objectName().isEmpty())
            ButtonPageWidget->setObjectName("ButtonPageWidget");
        ButtonPageWidget->resize(539, 430);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ButtonPageWidget->sizePolicy().hasHeightForWidth());
        ButtonPageWidget->setSizePolicy(sizePolicy);
        ButtonPageWidget->setLocale(QLocale(QLocale::English, QLocale::UnitedKingdom));
        verticalLayout = new QVBoxLayout(ButtonPageWidget);
        verticalLayout->setObjectName("verticalLayout");
        buttonGroupBox = new QGroupBox(ButtonPageWidget);
        buttonGroupBox->setObjectName("buttonGroupBox");
        horizontalLayout = new QHBoxLayout(buttonGroupBox);
        horizontalLayout->setObjectName("horizontalLayout");
        leftButtonLayout = new QFormLayout();
        leftButtonLayout->setObjectName("leftButtonLayout");
        button1Label = new QLabel(buttonGroupBox);
        button1Label->setObjectName("button1Label");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(button1Label->sizePolicy().hasHeightForWidth());
        button1Label->setSizePolicy(sizePolicy1);

        leftButtonLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, button1Label);

        button2Label = new QLabel(buttonGroupBox);
        button2Label->setObjectName("button2Label");
        sizePolicy1.setHeightForWidth(button2Label->sizePolicy().hasHeightForWidth());
        button2Label->setSizePolicy(sizePolicy1);

        leftButtonLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, button2Label);

        button3Label = new QLabel(buttonGroupBox);
        button3Label->setObjectName("button3Label");
        sizePolicy1.setHeightForWidth(button3Label->sizePolicy().hasHeightForWidth());
        button3Label->setSizePolicy(sizePolicy1);

        leftButtonLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, button3Label);

        button4Label = new QLabel(buttonGroupBox);
        button4Label->setObjectName("button4Label");
        sizePolicy1.setHeightForWidth(button4Label->sizePolicy().hasHeightForWidth());
        button4Label->setSizePolicy(sizePolicy1);

        leftButtonLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, button4Label);

        button5Label = new QLabel(buttonGroupBox);
        button5Label->setObjectName("button5Label");
        sizePolicy1.setHeightForWidth(button5Label->sizePolicy().hasHeightForWidth());
        button5Label->setSizePolicy(sizePolicy1);

        leftButtonLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, button5Label);

        button6Label = new QLabel(buttonGroupBox);
        button6Label->setObjectName("button6Label");
        sizePolicy1.setHeightForWidth(button6Label->sizePolicy().hasHeightForWidth());
        button6Label->setSizePolicy(sizePolicy1);

        leftButtonLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, button6Label);

        button7Label = new QLabel(buttonGroupBox);
        button7Label->setObjectName("button7Label");
        sizePolicy1.setHeightForWidth(button7Label->sizePolicy().hasHeightForWidth());
        button7Label->setSizePolicy(sizePolicy1);

        leftButtonLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, button7Label);

        button8Label = new QLabel(buttonGroupBox);
        button8Label->setObjectName("button8Label");
        sizePolicy1.setHeightForWidth(button8Label->sizePolicy().hasHeightForWidth());
        button8Label->setSizePolicy(sizePolicy1);

        leftButtonLayout->setWidget(7, QFormLayout::ItemRole::LabelRole, button8Label);

        button9Label = new QLabel(buttonGroupBox);
        button9Label->setObjectName("button9Label");
        sizePolicy1.setHeightForWidth(button9Label->sizePolicy().hasHeightForWidth());
        button9Label->setSizePolicy(sizePolicy1);

        leftButtonLayout->setWidget(8, QFormLayout::ItemRole::LabelRole, button9Label);

        leftButtonHSpacer = new QSpacerItem(100, 1, QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Minimum);

        leftButtonLayout->setItem(9, QFormLayout::ItemRole::FieldRole, leftButtonHSpacer);

        button1ActionSelector = new Wacom::ButtonActionSelectorWidget(buttonGroupBox);
        button1ActionSelector->setObjectName("button1ActionSelector");
        sizePolicy.setHeightForWidth(button1ActionSelector->sizePolicy().hasHeightForWidth());
        button1ActionSelector->setSizePolicy(sizePolicy);

        leftButtonLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, button1ActionSelector);

        button2ActionSelector = new Wacom::ButtonActionSelectorWidget(buttonGroupBox);
        button2ActionSelector->setObjectName("button2ActionSelector");
        sizePolicy.setHeightForWidth(button2ActionSelector->sizePolicy().hasHeightForWidth());
        button2ActionSelector->setSizePolicy(sizePolicy);

        leftButtonLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, button2ActionSelector);

        button3ActionSelector = new Wacom::ButtonActionSelectorWidget(buttonGroupBox);
        button3ActionSelector->setObjectName("button3ActionSelector");
        sizePolicy.setHeightForWidth(button3ActionSelector->sizePolicy().hasHeightForWidth());
        button3ActionSelector->setSizePolicy(sizePolicy);

        leftButtonLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, button3ActionSelector);

        button4ActionSelector = new Wacom::ButtonActionSelectorWidget(buttonGroupBox);
        button4ActionSelector->setObjectName("button4ActionSelector");
        sizePolicy.setHeightForWidth(button4ActionSelector->sizePolicy().hasHeightForWidth());
        button4ActionSelector->setSizePolicy(sizePolicy);

        leftButtonLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, button4ActionSelector);

        button5ActionSelector = new Wacom::ButtonActionSelectorWidget(buttonGroupBox);
        button5ActionSelector->setObjectName("button5ActionSelector");
        sizePolicy.setHeightForWidth(button5ActionSelector->sizePolicy().hasHeightForWidth());
        button5ActionSelector->setSizePolicy(sizePolicy);

        leftButtonLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, button5ActionSelector);

        button6ActionSelector = new Wacom::ButtonActionSelectorWidget(buttonGroupBox);
        button6ActionSelector->setObjectName("button6ActionSelector");
        sizePolicy.setHeightForWidth(button6ActionSelector->sizePolicy().hasHeightForWidth());
        button6ActionSelector->setSizePolicy(sizePolicy);

        leftButtonLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, button6ActionSelector);

        button7ActionSelector = new Wacom::ButtonActionSelectorWidget(buttonGroupBox);
        button7ActionSelector->setObjectName("button7ActionSelector");
        sizePolicy.setHeightForWidth(button7ActionSelector->sizePolicy().hasHeightForWidth());
        button7ActionSelector->setSizePolicy(sizePolicy);

        leftButtonLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, button7ActionSelector);

        button8ActionSelector = new Wacom::ButtonActionSelectorWidget(buttonGroupBox);
        button8ActionSelector->setObjectName("button8ActionSelector");
        sizePolicy.setHeightForWidth(button8ActionSelector->sizePolicy().hasHeightForWidth());
        button8ActionSelector->setSizePolicy(sizePolicy);

        leftButtonLayout->setWidget(7, QFormLayout::ItemRole::FieldRole, button8ActionSelector);

        button9ActionSelector = new Wacom::ButtonActionSelectorWidget(buttonGroupBox);
        button9ActionSelector->setObjectName("button9ActionSelector");
        sizePolicy.setHeightForWidth(button9ActionSelector->sizePolicy().hasHeightForWidth());
        button9ActionSelector->setSizePolicy(sizePolicy);

        leftButtonLayout->setWidget(8, QFormLayout::ItemRole::FieldRole, button9ActionSelector);


        horizontalLayout->addLayout(leftButtonLayout);

        padImageLayout = new QVBoxLayout();
        padImageLayout->setObjectName("padImageLayout");
        padImageLayout->setSizeConstraint(QLayout::SetFixedSize);
        padImage = new QLabel(buttonGroupBox);
        padImage->setObjectName("padImage");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(padImage->sizePolicy().hasHeightForWidth());
        padImage->setSizePolicy(sizePolicy2);
        padImage->setMinimumSize(QSize(200, 200));
        padImage->setAlignment(Qt::AlignCenter);

        padImageLayout->addWidget(padImage);

        padImageVSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        padImageLayout->addItem(padImageVSpacer);


        horizontalLayout->addLayout(padImageLayout);

        rightButtonLayout = new QFormLayout();
        rightButtonLayout->setObjectName("rightButtonLayout");
        button10Label = new QLabel(buttonGroupBox);
        button10Label->setObjectName("button10Label");
        sizePolicy1.setHeightForWidth(button10Label->sizePolicy().hasHeightForWidth());
        button10Label->setSizePolicy(sizePolicy1);

        rightButtonLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, button10Label);

        button11Label = new QLabel(buttonGroupBox);
        button11Label->setObjectName("button11Label");
        sizePolicy1.setHeightForWidth(button11Label->sizePolicy().hasHeightForWidth());
        button11Label->setSizePolicy(sizePolicy1);

        rightButtonLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, button11Label);

        button12Label = new QLabel(buttonGroupBox);
        button12Label->setObjectName("button12Label");
        sizePolicy1.setHeightForWidth(button12Label->sizePolicy().hasHeightForWidth());
        button12Label->setSizePolicy(sizePolicy1);

        rightButtonLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, button12Label);

        button13Label = new QLabel(buttonGroupBox);
        button13Label->setObjectName("button13Label");
        sizePolicy1.setHeightForWidth(button13Label->sizePolicy().hasHeightForWidth());
        button13Label->setSizePolicy(sizePolicy1);

        rightButtonLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, button13Label);

        button14Label = new QLabel(buttonGroupBox);
        button14Label->setObjectName("button14Label");
        sizePolicy1.setHeightForWidth(button14Label->sizePolicy().hasHeightForWidth());
        button14Label->setSizePolicy(sizePolicy1);

        rightButtonLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, button14Label);

        button15Label = new QLabel(buttonGroupBox);
        button15Label->setObjectName("button15Label");
        sizePolicy1.setHeightForWidth(button15Label->sizePolicy().hasHeightForWidth());
        button15Label->setSizePolicy(sizePolicy1);

        rightButtonLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, button15Label);

        button16Label = new QLabel(buttonGroupBox);
        button16Label->setObjectName("button16Label");
        sizePolicy1.setHeightForWidth(button16Label->sizePolicy().hasHeightForWidth());
        button16Label->setSizePolicy(sizePolicy1);

        rightButtonLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, button16Label);

        button17Label = new QLabel(buttonGroupBox);
        button17Label->setObjectName("button17Label");
        sizePolicy1.setHeightForWidth(button17Label->sizePolicy().hasHeightForWidth());
        button17Label->setSizePolicy(sizePolicy1);

        rightButtonLayout->setWidget(7, QFormLayout::ItemRole::LabelRole, button17Label);

        button18Label = new QLabel(buttonGroupBox);
        button18Label->setObjectName("button18Label");
        sizePolicy1.setHeightForWidth(button18Label->sizePolicy().hasHeightForWidth());
        button18Label->setSizePolicy(sizePolicy1);

        rightButtonLayout->setWidget(8, QFormLayout::ItemRole::LabelRole, button18Label);

        rightButtonHSpacer = new QSpacerItem(100, 1, QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Minimum);

        rightButtonLayout->setItem(9, QFormLayout::ItemRole::FieldRole, rightButtonHSpacer);

        button10ActionSelector = new Wacom::ButtonActionSelectorWidget(buttonGroupBox);
        button10ActionSelector->setObjectName("button10ActionSelector");
        sizePolicy.setHeightForWidth(button10ActionSelector->sizePolicy().hasHeightForWidth());
        button10ActionSelector->setSizePolicy(sizePolicy);

        rightButtonLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, button10ActionSelector);

        button11ActionSelector = new Wacom::ButtonActionSelectorWidget(buttonGroupBox);
        button11ActionSelector->setObjectName("button11ActionSelector");
        sizePolicy.setHeightForWidth(button11ActionSelector->sizePolicy().hasHeightForWidth());
        button11ActionSelector->setSizePolicy(sizePolicy);

        rightButtonLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, button11ActionSelector);

        button12ActionSelector = new Wacom::ButtonActionSelectorWidget(buttonGroupBox);
        button12ActionSelector->setObjectName("button12ActionSelector");
        sizePolicy.setHeightForWidth(button12ActionSelector->sizePolicy().hasHeightForWidth());
        button12ActionSelector->setSizePolicy(sizePolicy);

        rightButtonLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, button12ActionSelector);

        button13ActionSelector = new Wacom::ButtonActionSelectorWidget(buttonGroupBox);
        button13ActionSelector->setObjectName("button13ActionSelector");
        sizePolicy.setHeightForWidth(button13ActionSelector->sizePolicy().hasHeightForWidth());
        button13ActionSelector->setSizePolicy(sizePolicy);

        rightButtonLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, button13ActionSelector);

        button14ActionSelector = new Wacom::ButtonActionSelectorWidget(buttonGroupBox);
        button14ActionSelector->setObjectName("button14ActionSelector");
        sizePolicy.setHeightForWidth(button14ActionSelector->sizePolicy().hasHeightForWidth());
        button14ActionSelector->setSizePolicy(sizePolicy);

        rightButtonLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, button14ActionSelector);

        button15ActionSelector = new Wacom::ButtonActionSelectorWidget(buttonGroupBox);
        button15ActionSelector->setObjectName("button15ActionSelector");
        sizePolicy.setHeightForWidth(button15ActionSelector->sizePolicy().hasHeightForWidth());
        button15ActionSelector->setSizePolicy(sizePolicy);

        rightButtonLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, button15ActionSelector);

        button16ActionSelector = new Wacom::ButtonActionSelectorWidget(buttonGroupBox);
        button16ActionSelector->setObjectName("button16ActionSelector");
        sizePolicy.setHeightForWidth(button16ActionSelector->sizePolicy().hasHeightForWidth());
        button16ActionSelector->setSizePolicy(sizePolicy);

        rightButtonLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, button16ActionSelector);

        button17ActionSelector = new Wacom::ButtonActionSelectorWidget(buttonGroupBox);
        button17ActionSelector->setObjectName("button17ActionSelector");
        sizePolicy.setHeightForWidth(button17ActionSelector->sizePolicy().hasHeightForWidth());
        button17ActionSelector->setSizePolicy(sizePolicy);

        rightButtonLayout->setWidget(7, QFormLayout::ItemRole::FieldRole, button17ActionSelector);

        button18ActionSelector = new Wacom::ButtonActionSelectorWidget(buttonGroupBox);
        button18ActionSelector->setObjectName("button18ActionSelector");
        sizePolicy.setHeightForWidth(button18ActionSelector->sizePolicy().hasHeightForWidth());
        button18ActionSelector->setSizePolicy(sizePolicy);

        rightButtonLayout->setWidget(8, QFormLayout::ItemRole::FieldRole, button18ActionSelector);


        horizontalLayout->addLayout(rightButtonLayout);


        verticalLayout->addWidget(buttonGroupBox);

        touchStripGroupBox = new QGroupBox(ButtonPageWidget);
        touchStripGroupBox->setObjectName("touchStripGroupBox");
        horizontalLayout_2 = new QHBoxLayout(touchStripGroupBox);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        leftStripWidget = new QWidget(touchStripGroupBox);
        leftStripWidget->setObjectName("leftStripWidget");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(leftStripWidget->sizePolicy().hasHeightForWidth());
        leftStripWidget->setSizePolicy(sizePolicy3);
        formLayout = new QFormLayout(leftStripWidget);
        formLayout->setContentsMargins(0, 0, 0, 0);
        formLayout->setObjectName("formLayout");
        leftStripUpLabel = new QLabel(leftStripWidget);
        leftStripUpLabel->setObjectName("leftStripUpLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, leftStripUpLabel);

        leftStripUpSelector = new Wacom::ButtonActionSelectorWidget(leftStripWidget);
        leftStripUpSelector->setObjectName("leftStripUpSelector");
        sizePolicy.setHeightForWidth(leftStripUpSelector->sizePolicy().hasHeightForWidth());
        leftStripUpSelector->setSizePolicy(sizePolicy);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, leftStripUpSelector);

        leftStripDownLabel = new QLabel(leftStripWidget);
        leftStripDownLabel->setObjectName("leftStripDownLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, leftStripDownLabel);

        leftStripDownSelector = new Wacom::ButtonActionSelectorWidget(leftStripWidget);
        leftStripDownSelector->setObjectName("leftStripDownSelector");
        sizePolicy.setHeightForWidth(leftStripDownSelector->sizePolicy().hasHeightForWidth());
        leftStripDownSelector->setSizePolicy(sizePolicy);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, leftStripDownSelector);


        horizontalLayout_2->addWidget(leftStripWidget);

        stripHSpacer = new QSpacerItem(200, 1, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(stripHSpacer);

        rightStripWidget = new QWidget(touchStripGroupBox);
        rightStripWidget->setObjectName("rightStripWidget");
        sizePolicy3.setHeightForWidth(rightStripWidget->sizePolicy().hasHeightForWidth());
        rightStripWidget->setSizePolicy(sizePolicy3);
        formLayout_2 = new QFormLayout(rightStripWidget);
        formLayout_2->setContentsMargins(0, 0, 0, 0);
        formLayout_2->setObjectName("formLayout_2");
        rightStripUpLabel = new QLabel(rightStripWidget);
        rightStripUpLabel->setObjectName("rightStripUpLabel");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, rightStripUpLabel);

        rightStripUpSelector = new Wacom::ButtonActionSelectorWidget(rightStripWidget);
        rightStripUpSelector->setObjectName("rightStripUpSelector");
        sizePolicy.setHeightForWidth(rightStripUpSelector->sizePolicy().hasHeightForWidth());
        rightStripUpSelector->setSizePolicy(sizePolicy);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, rightStripUpSelector);

        rightStripDownLabel = new QLabel(rightStripWidget);
        rightStripDownLabel->setObjectName("rightStripDownLabel");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, rightStripDownLabel);

        rightStripDownSelector = new Wacom::ButtonActionSelectorWidget(rightStripWidget);
        rightStripDownSelector->setObjectName("rightStripDownSelector");
        sizePolicy.setHeightForWidth(rightStripDownSelector->sizePolicy().hasHeightForWidth());
        rightStripDownSelector->setSizePolicy(sizePolicy);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, rightStripDownSelector);


        horizontalLayout_2->addWidget(rightStripWidget);


        verticalLayout->addWidget(touchStripGroupBox);

        touchRingGroupBox = new QGroupBox(ButtonPageWidget);
        touchRingGroupBox->setObjectName("touchRingGroupBox");
        horizontalLayout_3 = new QHBoxLayout(touchRingGroupBox);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        leftRingLayout = new QFormLayout();
        leftRingLayout->setObjectName("leftRingLayout");
        leftRingLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        ringUpLabel = new QLabel(touchRingGroupBox);
        ringUpLabel->setObjectName("ringUpLabel");

        leftRingLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, ringUpLabel);

        ringUpSelector = new Wacom::ButtonActionSelectorWidget(touchRingGroupBox);
        ringUpSelector->setObjectName("ringUpSelector");
        sizePolicy.setHeightForWidth(ringUpSelector->sizePolicy().hasHeightForWidth());
        ringUpSelector->setSizePolicy(sizePolicy);

        leftRingLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, ringUpSelector);


        horizontalLayout_3->addLayout(leftRingLayout);

        ringHSpacer = new QSpacerItem(200, 1, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(ringHSpacer);

        rightRingLayout = new QFormLayout();
        rightRingLayout->setObjectName("rightRingLayout");
        rightRingLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        ringDownLabel = new QLabel(touchRingGroupBox);
        ringDownLabel->setObjectName("ringDownLabel");

        rightRingLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, ringDownLabel);

        ringDownSelector = new Wacom::ButtonActionSelectorWidget(touchRingGroupBox);
        ringDownSelector->setObjectName("ringDownSelector");
        sizePolicy.setHeightForWidth(ringDownSelector->sizePolicy().hasHeightForWidth());
        ringDownSelector->setSizePolicy(sizePolicy);

        rightRingLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, ringDownSelector);


        horizontalLayout_3->addLayout(rightRingLayout);


        verticalLayout->addWidget(touchRingGroupBox);

        wheelGroupBox = new QGroupBox(ButtonPageWidget);
        wheelGroupBox->setObjectName("wheelGroupBox");
        horizontalLayout_4 = new QHBoxLayout(wheelGroupBox);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        leftWheelLayout = new QFormLayout();
        leftWheelLayout->setObjectName("leftWheelLayout");
        wheelUpLabel = new QLabel(wheelGroupBox);
        wheelUpLabel->setObjectName("wheelUpLabel");

        leftWheelLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, wheelUpLabel);

        wheelUpSelector = new Wacom::ButtonActionSelectorWidget(wheelGroupBox);
        wheelUpSelector->setObjectName("wheelUpSelector");
        sizePolicy.setHeightForWidth(wheelUpSelector->sizePolicy().hasHeightForWidth());
        wheelUpSelector->setSizePolicy(sizePolicy);

        leftWheelLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, wheelUpSelector);


        horizontalLayout_4->addLayout(leftWheelLayout);

        wheelHSpacer = new QSpacerItem(200, 1, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(wheelHSpacer);

        rightWheelLayout = new QFormLayout();
        rightWheelLayout->setObjectName("rightWheelLayout");
        wheelDownLabel = new QLabel(wheelGroupBox);
        wheelDownLabel->setObjectName("wheelDownLabel");

        rightWheelLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, wheelDownLabel);

        wheelDownSelector = new Wacom::ButtonActionSelectorWidget(wheelGroupBox);
        wheelDownSelector->setObjectName("wheelDownSelector");
        sizePolicy.setHeightForWidth(wheelDownSelector->sizePolicy().hasHeightForWidth());
        wheelDownSelector->setSizePolicy(sizePolicy);

        rightWheelLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, wheelDownSelector);


        horizontalLayout_4->addLayout(rightWheelLayout);


        verticalLayout->addWidget(wheelGroupBox);

        freeSpaceVSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(freeSpaceVSpacer);


        retranslateUi(ButtonPageWidget);

        QMetaObject::connectSlotsByName(ButtonPageWidget);
    } // setupUi

    void retranslateUi(QWidget *ButtonPageWidget)
    {
        ButtonPageWidget->setWindowTitle(tr2i18n("Pad Buttons", nullptr));
        buttonGroupBox->setTitle(tr2i18n("Express Buttons", nullptr));
        button1Label->setText(tr2i18n("Button 1", nullptr));
        button2Label->setText(tr2i18n("Button 2", nullptr));
        button3Label->setText(tr2i18n("Button 3", nullptr));
        button4Label->setText(tr2i18n("Button 4", nullptr));
        button5Label->setText(tr2i18n("Button 5", nullptr));
        button6Label->setText(tr2i18n("Button 6", nullptr));
        button7Label->setText(tr2i18n("Button 7", nullptr));
        button8Label->setText(tr2i18n("Button 8", nullptr));
        button9Label->setText(tr2i18n("Button 9", nullptr));
        padImage->setText(QString());
        button10Label->setText(tr2i18n("Button 10", nullptr));
        button11Label->setText(tr2i18n("Button 11", nullptr));
        button12Label->setText(tr2i18n("Button 12", nullptr));
        button13Label->setText(tr2i18n("Button 13", nullptr));
        button14Label->setText(tr2i18n("Button 14", nullptr));
        button15Label->setText(tr2i18n("Button 15", nullptr));
        button16Label->setText(tr2i18n("Button 16", nullptr));
        button17Label->setText(tr2i18n("Button 17", nullptr));
        button18Label->setText(tr2i18n("Button 18", nullptr));
        touchStripGroupBox->setTitle(tr2i18n("Touch Strip", nullptr));
        leftStripUpLabel->setText(tr2i18n("Left Strip Up", nullptr));
        leftStripDownLabel->setText(tr2i18n("Left Strip Down", nullptr));
        rightStripUpLabel->setText(tr2i18n("Right Strip Up", nullptr));
        rightStripDownLabel->setText(tr2i18n("Right Strip Down", nullptr));
        touchRingGroupBox->setTitle(tr2i18n("Touch Ring", nullptr));
        ringUpLabel->setText(tr2i18n("Ring Up", nullptr));
        ringDownLabel->setText(tr2i18n("Ring Down", nullptr));
        wheelGroupBox->setTitle(tr2i18n("Wheel", nullptr));
        wheelUpLabel->setText(tr2i18n("Wheel Up", nullptr));
        wheelDownLabel->setText(tr2i18n("Wheel Down", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ButtonPageWidget: public Ui_ButtonPageWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BUTTONPAGEWIDGET_H

