/********************************************************************************
** Form generated from reading UI file 'hwbuttondialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_HWBUTTONDIALOG_H
#define UI_HWBUTTONDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_HWButtonDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QTextEdit *textEdit;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *HWButtonDialog)
    {
        if (HWButtonDialog->objectName().isEmpty())
            HWButtonDialog->setObjectName("HWButtonDialog");
        HWButtonDialog->resize(400, 432);
        verticalLayout = new QVBoxLayout(HWButtonDialog);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(HWButtonDialog);
        label->setObjectName("label");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);
        label->setWordWrap(true);

        verticalLayout->addWidget(label);

        textEdit = new QTextEdit(HWButtonDialog);
        textEdit->setObjectName("textEdit");
        textEdit->setUndoRedoEnabled(false);
        textEdit->setReadOnly(true);
        textEdit->setTextInteractionFlags(Qt::NoTextInteraction);

        verticalLayout->addWidget(textEdit);

        buttonBox = new QDialogButtonBox(HWButtonDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(HWButtonDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, HWButtonDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, HWButtonDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(HWButtonDialog);
    } // setupUi

    void retranslateUi(QDialog *HWButtonDialog)
    {
        HWButtonDialog->setWindowTitle(tr2i18n("Dialog", nullptr));
        label->setText(tr2i18n("Move the mouse cursor inside the dialog but <b>do not</b> click into it with the mouse.", nullptr));
    } // retranslateUi

};

namespace Ui {
    class HWButtonDialog: public Ui_HWButtonDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // HWBUTTONDIALOG_H

