/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Wacom.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef WACOMINTERFACE_H
#define WACOMINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.Wacom
 */
class OrgKdeWacomInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.Wacom"; }

public:
    OrgKdeWacomInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeWacomInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<QStringList> getDeviceList(const QString &tabletId)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(tabletId);
        return asyncCallWithArgumentList(QStringLiteral("getDeviceList"), argumentList);
    }

    inline QDBusPendingReply<QString> getDeviceName(const QString &tabletId, const QString &device)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(tabletId) << QVariant::fromValue(device);
        return asyncCallWithArgumentList(QStringLiteral("getDeviceName"), argumentList);
    }

    inline QDBusPendingReply<QString> getInformation(const QString &tabletId, const QString &info)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(tabletId) << QVariant::fromValue(info);
        return asyncCallWithArgumentList(QStringLiteral("getInformation"), argumentList);
    }

    inline QDBusPendingReply<QString> getProfile(const QString &tabletId)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(tabletId);
        return asyncCallWithArgumentList(QStringLiteral("getProfile"), argumentList);
    }

    inline QDBusPendingReply<QStringList> getProfileRotationList(const QString &tabletId)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(tabletId);
        return asyncCallWithArgumentList(QStringLiteral("getProfileRotationList"), argumentList);
    }

    inline QDBusPendingReply<QString> getProperty(const QString &tabletId, const QString &device, const QString &param)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(tabletId) << QVariant::fromValue(device) << QVariant::fromValue(param);
        return asyncCallWithArgumentList(QStringLiteral("getProperty"), argumentList);
    }

    inline QDBusPendingReply<QStringList> getTabletList()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("getTabletList"), argumentList);
    }

    inline QDBusPendingReply<QString> getTouchSensorId(const QString &tabletId)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(tabletId);
        return asyncCallWithArgumentList(QStringLiteral("getTouchSensorId"), argumentList);
    }

    inline QDBusPendingReply<bool> hasPadButtons(const QString &tabletId)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(tabletId);
        return asyncCallWithArgumentList(QStringLiteral("hasPadButtons"), argumentList);
    }

    inline QDBusPendingReply<bool> isAvailable(const QString &tabletId)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(tabletId);
        return asyncCallWithArgumentList(QStringLiteral("isAvailable"), argumentList);
    }

    inline QDBusPendingReply<bool> isTouchSensor(const QString &tabletId)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(tabletId);
        return asyncCallWithArgumentList(QStringLiteral("isTouchSensor"), argumentList);
    }

    inline QDBusPendingReply<QStringList> listProfiles(const QString &tabletId)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(tabletId);
        return asyncCallWithArgumentList(QStringLiteral("listProfiles"), argumentList);
    }

    inline QDBusPendingReply<> setProfile(const QString &tabletId, const QString &profile)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(tabletId) << QVariant::fromValue(profile);
        return asyncCallWithArgumentList(QStringLiteral("setProfile"), argumentList);
    }

    inline QDBusPendingReply<> setProfileRotationList(const QString &tabletId, const QStringList &in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(tabletId) << QVariant::fromValue(in1);
        return asyncCallWithArgumentList(QStringLiteral("setProfileRotationList"), argumentList);
    }

    inline QDBusPendingReply<> setProperty(const QString &tabletId, const QString &device, const QString &param, const QString &value)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(tabletId) << QVariant::fromValue(device) << QVariant::fromValue(param) << QVariant::fromValue(value);
        return asyncCallWithArgumentList(QStringLiteral("setProperty"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void profileChanged(const QString &tabletId, const QString &profile);
    void tabletAdded(const QString &tabletId);
    void tabletRemoved(const QString &tabletId);
};

namespace org {
  namespace kde {
    using Wacom = ::OrgKdeWacomInterface;
  }
}

#endif
