/********************************************************************************
** Form generated from reading UI file 'generalpagewidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GENERALPAGEWIDGET_H
#define UI_GENERALPAGEWIDGET_H

#include <QtCore/QLocale>
#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_GeneralPageWidget
{
public:
    QVBoxLayout *verticalLayout_3;
    QGroupBox *profileRotationBox;
    QHBoxLayout *horizontalLayout;
    QListWidget *lwRotationList;
    QVBoxLayout *verticalLayout_2;
    QSpacerItem *verticalSpacer_2;
    QGridLayout *gridLayout;
    QPushButton *pbDown;
    QPushButton *pbRemoveFromRotationList;
    QPushButton *pbAddToRotationList;
    QPushButton *pbUp;
    QSpacerItem *verticalSpacer;
    QGroupBox *shortcutGroupBox;
    QVBoxLayout *verticalLayout;

    void setupUi(QWidget *GeneralPageWidget)
    {
        if (GeneralPageWidget->objectName().isEmpty())
            GeneralPageWidget->setObjectName("GeneralPageWidget");
        GeneralPageWidget->resize(787, 807);
        GeneralPageWidget->setLocale(QLocale(QLocale::English, QLocale::UnitedKingdom));
        verticalLayout_3 = new QVBoxLayout(GeneralPageWidget);
        verticalLayout_3->setObjectName("verticalLayout_3");
        profileRotationBox = new QGroupBox(GeneralPageWidget);
        profileRotationBox->setObjectName("profileRotationBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(profileRotationBox->sizePolicy().hasHeightForWidth());
        profileRotationBox->setSizePolicy(sizePolicy);
        profileRotationBox->setMinimumSize(QSize(0, 100));
        horizontalLayout = new QHBoxLayout(profileRotationBox);
        horizontalLayout->setObjectName("horizontalLayout");
        lwRotationList = new QListWidget(profileRotationBox);
        lwRotationList->setObjectName("lwRotationList");
        lwRotationList->setMaximumSize(QSize(16777215, 16777215));
        lwRotationList->setEditTriggers(QAbstractItemView::NoEditTriggers);
        lwRotationList->setProperty("showDropIndicator", QVariant(false));
        lwRotationList->setAlternatingRowColors(true);
        lwRotationList->setSortingEnabled(false);

        horizontalLayout->addWidget(lwRotationList);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_2);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        pbDown = new QPushButton(profileRotationBox);
        pbDown->setObjectName("pbDown");

        gridLayout->addWidget(pbDown, 1, 0, 1, 1);

        pbRemoveFromRotationList = new QPushButton(profileRotationBox);
        pbRemoveFromRotationList->setObjectName("pbRemoveFromRotationList");

        gridLayout->addWidget(pbRemoveFromRotationList, 1, 1, 1, 1);

        pbAddToRotationList = new QPushButton(profileRotationBox);
        pbAddToRotationList->setObjectName("pbAddToRotationList");

        gridLayout->addWidget(pbAddToRotationList, 0, 1, 1, 1);

        pbUp = new QPushButton(profileRotationBox);
        pbUp->setObjectName("pbUp");

        gridLayout->addWidget(pbUp, 0, 0, 1, 1);


        verticalLayout_2->addLayout(gridLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);


        horizontalLayout->addLayout(verticalLayout_2);


        verticalLayout_3->addWidget(profileRotationBox);

        shortcutGroupBox = new QGroupBox(GeneralPageWidget);
        shortcutGroupBox->setObjectName("shortcutGroupBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(shortcutGroupBox->sizePolicy().hasHeightForWidth());
        shortcutGroupBox->setSizePolicy(sizePolicy1);
        shortcutGroupBox->setMinimumSize(QSize(0, 200));
        verticalLayout = new QVBoxLayout(shortcutGroupBox);
        verticalLayout->setObjectName("verticalLayout");

        verticalLayout_3->addWidget(shortcutGroupBox);


        retranslateUi(GeneralPageWidget);
        QObject::connect(pbAddToRotationList, SIGNAL(clicked()), GeneralPageWidget, SLOT(profileAdd()));
        QObject::connect(pbDown, SIGNAL(clicked()), GeneralPageWidget, SLOT(profileDown()));
        QObject::connect(pbRemoveFromRotationList, SIGNAL(clicked()), GeneralPageWidget, SLOT(profileRemove()));
        QObject::connect(pbUp, SIGNAL(clicked()), GeneralPageWidget, SLOT(profileUp()));

        QMetaObject::connectSlotsByName(GeneralPageWidget);
    } // setupUi

    void retranslateUi(QWidget *GeneralPageWidget)
    {
        GeneralPageWidget->setWindowTitle(tr2i18n("General Hardware Overview", nullptr));
        profileRotationBox->setTitle(tr2i18n("Profile rotation", nullptr));
        pbDown->setText(tr2i18n("Down", nullptr));
        pbRemoveFromRotationList->setText(tr2i18n("Remove", nullptr));
        pbAddToRotationList->setText(tr2i18n("Add", nullptr));
        pbUp->setText(tr2i18n("Up", nullptr));
        shortcutGroupBox->setTitle(tr2i18n("Shortcuts", nullptr));
    } // retranslateUi

};

namespace Ui {
    class GeneralPageWidget: public Ui_GeneralPageWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GENERALPAGEWIDGET_H

