/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Wacom.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef WACOMADAPTOR_H
#define WACOMADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "dbustabletservice.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.Wacom
 */
class WacomAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.Wacom")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.Wacom\">\n"
"    <method name=\"getTabletList\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"getDeviceList\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"tabletId\"/>\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"getDeviceName\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"tabletId\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"device\"/>\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"getTouchSensorId\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"tabletId\"/>\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"getInformation\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"tabletId\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"info\"/>\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"getProfile\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"tabletId\"/>\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"getProperty\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"tabletId\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"device\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"param\"/>\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"hasPadButtons\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"tabletId\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"isTouchSensor\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"tabletId\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"isAvailable\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"tabletId\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"listProfiles\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"tabletId\"/>\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"setProfile\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"tabletId\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"profile\"/>\n"
"    </method>\n"
"    <method name=\"setProperty\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"tabletId\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"device\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"param\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"value\"/>\n"
"    </method>\n"
"    <method name=\"getProfileRotationList\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"tabletId\"/>\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"setProfileRotationList\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"tabletId\"/>\n"
"      <arg direction=\"in\" type=\"as\"/>\n"
"    </method>\n"
"    <signal name=\"profileChanged\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"tabletId\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"profile\"/>\n"
"    </signal>\n"
"    <signal name=\"tabletAdded\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"tabletId\"/>\n"
"    </signal>\n"
"    <signal name=\"tabletRemoved\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"tabletId\"/>\n"
"    </signal>\n"
"  </interface>\n"
        "")
public:
    WacomAdaptor(Wacom::DBusTabletService *parent);
    ~WacomAdaptor() override;

    inline Wacom::DBusTabletService *parent() const
    { return static_cast<Wacom::DBusTabletService *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    QStringList getDeviceList(const QString &tabletId);
    QString getDeviceName(const QString &tabletId, const QString &device);
    QString getInformation(const QString &tabletId, const QString &info);
    QString getProfile(const QString &tabletId);
    QStringList getProfileRotationList(const QString &tabletId);
    QString getProperty(const QString &tabletId, const QString &device, const QString &param);
    QStringList getTabletList();
    QString getTouchSensorId(const QString &tabletId);
    bool hasPadButtons(const QString &tabletId);
    bool isAvailable(const QString &tabletId);
    bool isTouchSensor(const QString &tabletId);
    QStringList listProfiles(const QString &tabletId);
    void setProfile(const QString &tabletId, const QString &profile);
    void setProfileRotationList(const QString &tabletId, const QStringList &in1);
    void setProperty(const QString &tabletId, const QString &device, const QString &param, const QString &value);
Q_SIGNALS: // SIGNALS
    void profileChanged(const QString &tabletId, const QString &profile);
    void tabletAdded(const QString &tabletId);
    void tabletRemoved(const QString &tabletId);
};

#endif
