/********************************************************************************
** Form generated from reading UI file 'buttonactionselectorwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BUTTONACTIONSELECTORWIDGET_H
#define UI_BUTTONACTIONSELECTORWIDGET_H

#include <QtCore/QLocale>
#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "buttonactiondisplaywidget.h"

QT_BEGIN_NAMESPACE

class Ui_ButtonActionSelectorWidget
{
public:
    QHBoxLayout *horizontalLayout_2;
    QPushButton *actionSelectionButton;
    Wacom::ButtonActionDisplayWidget *actionNameDisplayWidget;

    void setupUi(QWidget *ButtonActionSelectorWidget)
    {
        if (ButtonActionSelectorWidget->objectName().isEmpty())
            ButtonActionSelectorWidget->setObjectName("ButtonActionSelectorWidget");
        ButtonActionSelectorWidget->setEnabled(true);
        ButtonActionSelectorWidget->resize(200, 33);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ButtonActionSelectorWidget->sizePolicy().hasHeightForWidth());
        ButtonActionSelectorWidget->setSizePolicy(sizePolicy);
        ButtonActionSelectorWidget->setMinimumSize(QSize(200, 0));
        ButtonActionSelectorWidget->setLocale(QLocale(QLocale::English, QLocale::UnitedStates));
        horizontalLayout_2 = new QHBoxLayout(ButtonActionSelectorWidget);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        actionSelectionButton = new QPushButton(ButtonActionSelectorWidget);
        actionSelectionButton->setObjectName("actionSelectionButton");
        actionSelectionButton->setMaximumSize(QSize(25, 16777215));
        actionSelectionButton->setFlat(true);

        horizontalLayout_2->addWidget(actionSelectionButton);

        actionNameDisplayWidget = new Wacom::ButtonActionDisplayWidget(ButtonActionSelectorWidget);
        actionNameDisplayWidget->setObjectName("actionNameDisplayWidget");
        actionNameDisplayWidget->setReadOnly(true);

        horizontalLayout_2->addWidget(actionNameDisplayWidget);


        retranslateUi(ButtonActionSelectorWidget);

        QMetaObject::connectSlotsByName(ButtonActionSelectorWidget);
    } // setupUi

    void retranslateUi(QWidget *ButtonActionSelectorWidget)
    {
        actionNameDisplayWidget->setPlaceholderText(tr2i18n("Click to assign an action.", nullptr));
        (void)ButtonActionSelectorWidget;
    } // retranslateUi

};

namespace Ui {
    class ButtonActionSelectorWidget: public Ui_ButtonActionSelectorWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BUTTONACTIONSELECTORWIDGET_H

