/********************************************************************************
** Form generated from reading UI file 'tabletareaselectionview.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TABLETAREASELECTIONVIEW_H
#define UI_TABLETAREASELECTIONVIEW_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "areaselectionwidget.h"

QT_BEGIN_NAMESPACE

class Ui_TabletAreaSelectionView
{
public:
    QVBoxLayout *verticalLayout_4;
    QHBoxLayout *infoLayout;
    QLabel *iconLabel;
    QLabel *infoLabel;
    QHBoxLayout *horizontalLayout;
    QVBoxLayout *controlsLayout;
    QGroupBox *screenGroupBox;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *screenCenterLayout;
    Wacom::AreaSelectionWidget *screenArea;
    QPushButton *screenToggleButton;
    QGroupBox *controlsGroupBox;
    QVBoxLayout *verticalLayout_2;
    QRadioButton *fullTabletRadioButton;
    QRadioButton *tabletAreaRadioButton;
    QPushButton *forceProportionsButton;
    QPushButton *calibrateButton;
    QSpacerItem *controlsFreeSpacer;
    QGroupBox *tabletGroupBox;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *areaCenterLayout;
    Wacom::AreaSelectionWidget *areaWidget;
    QHBoxLayout *warningLayout;
    QLabel *warningIcon;
    QLabel *warningLabel;
    QPushButton *buttonLockProportions;
    QGroupBox *fineTuneGroupBox;
    QGridLayout *gridLayout;
    QLineEdit *lineEditWidth;
    QLabel *labelHorizontalTune;
    QLineEdit *lineEditX;
    QLabel *labelVerticalTune;
    QLineEdit *lineEditY;
    QLineEdit *lineEditHeight;
    QSpacerItem *tabletFreeSpacer;

    void setupUi(QWidget *TabletAreaSelectionView)
    {
        if (TabletAreaSelectionView->objectName().isEmpty())
            TabletAreaSelectionView->setObjectName("TabletAreaSelectionView");
        TabletAreaSelectionView->resize(669, 312);
        verticalLayout_4 = new QVBoxLayout(TabletAreaSelectionView);
        verticalLayout_4->setObjectName("verticalLayout_4");
        infoLayout = new QHBoxLayout();
        infoLayout->setObjectName("infoLayout");
        iconLabel = new QLabel(TabletAreaSelectionView);
        iconLabel->setObjectName("iconLabel");
        iconLabel->setMinimumSize(QSize(16, 16));
        iconLabel->setMaximumSize(QSize(16, 16));
        iconLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        infoLayout->addWidget(iconLabel);

        infoLabel = new QLabel(TabletAreaSelectionView);
        infoLabel->setObjectName("infoLabel");
        infoLabel->setWordWrap(true);

        infoLayout->addWidget(infoLabel);


        verticalLayout_4->addLayout(infoLayout);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        controlsLayout = new QVBoxLayout();
        controlsLayout->setObjectName("controlsLayout");
        screenGroupBox = new QGroupBox(TabletAreaSelectionView);
        screenGroupBox->setObjectName("screenGroupBox");
        screenGroupBox->setAlignment(Qt::AlignCenter);
        verticalLayout = new QVBoxLayout(screenGroupBox);
        verticalLayout->setObjectName("verticalLayout");
        screenCenterLayout = new QHBoxLayout();
        screenCenterLayout->setObjectName("screenCenterLayout");
        screenArea = new Wacom::AreaSelectionWidget(screenGroupBox);
        screenArea->setObjectName("screenArea");
        screenArea->setEnabled(true);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(screenArea->sizePolicy().hasHeightForWidth());
        screenArea->setSizePolicy(sizePolicy);

        screenCenterLayout->addWidget(screenArea);


        verticalLayout->addLayout(screenCenterLayout);

        screenToggleButton = new QPushButton(screenGroupBox);
        screenToggleButton->setObjectName("screenToggleButton");

        verticalLayout->addWidget(screenToggleButton);


        controlsLayout->addWidget(screenGroupBox);

        controlsGroupBox = new QGroupBox(TabletAreaSelectionView);
        controlsGroupBox->setObjectName("controlsGroupBox");
        verticalLayout_2 = new QVBoxLayout(controlsGroupBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        fullTabletRadioButton = new QRadioButton(controlsGroupBox);
        fullTabletRadioButton->setObjectName("fullTabletRadioButton");
        fullTabletRadioButton->setChecked(true);

        verticalLayout_2->addWidget(fullTabletRadioButton);

        tabletAreaRadioButton = new QRadioButton(controlsGroupBox);
        tabletAreaRadioButton->setObjectName("tabletAreaRadioButton");

        verticalLayout_2->addWidget(tabletAreaRadioButton);

        forceProportionsButton = new QPushButton(controlsGroupBox);
        forceProportionsButton->setObjectName("forceProportionsButton");

        verticalLayout_2->addWidget(forceProportionsButton);

        calibrateButton = new QPushButton(controlsGroupBox);
        calibrateButton->setObjectName("calibrateButton");

        verticalLayout_2->addWidget(calibrateButton);


        controlsLayout->addWidget(controlsGroupBox);

        controlsFreeSpacer = new QSpacerItem(1, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        controlsLayout->addItem(controlsFreeSpacer);


        horizontalLayout->addLayout(controlsLayout);

        tabletGroupBox = new QGroupBox(TabletAreaSelectionView);
        tabletGroupBox->setObjectName("tabletGroupBox");
        verticalLayout_3 = new QVBoxLayout(tabletGroupBox);
        verticalLayout_3->setObjectName("verticalLayout_3");
        areaCenterLayout = new QHBoxLayout();
        areaCenterLayout->setObjectName("areaCenterLayout");
        areaWidget = new Wacom::AreaSelectionWidget(tabletGroupBox);
        areaWidget->setObjectName("areaWidget");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(areaWidget->sizePolicy().hasHeightForWidth());
        areaWidget->setSizePolicy(sizePolicy1);

        areaCenterLayout->addWidget(areaWidget);


        verticalLayout_3->addLayout(areaCenterLayout);

        warningLayout = new QHBoxLayout();
        warningLayout->setObjectName("warningLayout");
        warningIcon = new QLabel(tabletGroupBox);
        warningIcon->setObjectName("warningIcon");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(warningIcon->sizePolicy().hasHeightForWidth());
        warningIcon->setSizePolicy(sizePolicy2);
        warningIcon->setMinimumSize(QSize(16, 16));
        warningIcon->setMaximumSize(QSize(16, 16));

        warningLayout->addWidget(warningIcon);

        warningLabel = new QLabel(tabletGroupBox);
        warningLabel->setObjectName("warningLabel");
        warningLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        warningLabel->setWordWrap(true);

        warningLayout->addWidget(warningLabel);


        verticalLayout_3->addLayout(warningLayout);

        buttonLockProportions = new QPushButton(tabletGroupBox);
        buttonLockProportions->setObjectName("buttonLockProportions");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("lock")));
        buttonLockProportions->setIcon(icon);
        buttonLockProportions->setCheckable(true);

        verticalLayout_3->addWidget(buttonLockProportions);

        fineTuneGroupBox = new QGroupBox(tabletGroupBox);
        fineTuneGroupBox->setObjectName("fineTuneGroupBox");
        gridLayout = new QGridLayout(fineTuneGroupBox);
        gridLayout->setObjectName("gridLayout");
        lineEditWidth = new QLineEdit(fineTuneGroupBox);
        lineEditWidth->setObjectName("lineEditWidth");
        sizePolicy2.setHeightForWidth(lineEditWidth->sizePolicy().hasHeightForWidth());
        lineEditWidth->setSizePolicy(sizePolicy2);
        lineEditWidth->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(lineEditWidth, 0, 2, 1, 1);

        labelHorizontalTune = new QLabel(fineTuneGroupBox);
        labelHorizontalTune->setObjectName("labelHorizontalTune");

        gridLayout->addWidget(labelHorizontalTune, 0, 0, 1, 1);

        lineEditX = new QLineEdit(fineTuneGroupBox);
        lineEditX->setObjectName("lineEditX");
        sizePolicy2.setHeightForWidth(lineEditX->sizePolicy().hasHeightForWidth());
        lineEditX->setSizePolicy(sizePolicy2);
        lineEditX->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(lineEditX, 0, 1, 1, 1);

        labelVerticalTune = new QLabel(fineTuneGroupBox);
        labelVerticalTune->setObjectName("labelVerticalTune");

        gridLayout->addWidget(labelVerticalTune, 1, 0, 1, 1);

        lineEditY = new QLineEdit(fineTuneGroupBox);
        lineEditY->setObjectName("lineEditY");
        sizePolicy2.setHeightForWidth(lineEditY->sizePolicy().hasHeightForWidth());
        lineEditY->setSizePolicy(sizePolicy2);
        lineEditY->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(lineEditY, 1, 1, 1, 1);

        lineEditHeight = new QLineEdit(fineTuneGroupBox);
        lineEditHeight->setObjectName("lineEditHeight");
        sizePolicy2.setHeightForWidth(lineEditHeight->sizePolicy().hasHeightForWidth());
        lineEditHeight->setSizePolicy(sizePolicy2);
        lineEditHeight->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(lineEditHeight, 1, 2, 1, 1);


        verticalLayout_3->addWidget(fineTuneGroupBox);

        tabletFreeSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        verticalLayout_3->addItem(tabletFreeSpacer);


        horizontalLayout->addWidget(tabletGroupBox);


        verticalLayout_4->addLayout(horizontalLayout);


        retranslateUi(TabletAreaSelectionView);
        QObject::connect(calibrateButton, SIGNAL(clicked()), TabletAreaSelectionView, SLOT(onCalibrateClicked()));
        QObject::connect(forceProportionsButton, SIGNAL(clicked()), TabletAreaSelectionView, SLOT(onForceProportionsClicked()));
        QObject::connect(fullTabletRadioButton, SIGNAL(toggled(bool)), TabletAreaSelectionView, SLOT(onFullTabletSelected(bool)));
        QObject::connect(tabletAreaRadioButton, SIGNAL(toggled(bool)), TabletAreaSelectionView, SLOT(onTabletAreaSelected(bool)));
        QObject::connect(screenToggleButton, SIGNAL(clicked()), TabletAreaSelectionView, SLOT(onScreenToggle()));
        QObject::connect(buttonLockProportions, SIGNAL(toggled(bool)), TabletAreaSelectionView, SLOT(onLockProportionsToggled(bool)));

        QMetaObject::connectSlotsByName(TabletAreaSelectionView);
    } // setupUi

    void retranslateUi(QWidget *TabletAreaSelectionView)
    {
        iconLabel->setText(QString());
        infoLabel->setText(tr2i18n("The tablet area defines how the screen space is mapped to your tablet. For each screen a different tablet area can be selected. ", nullptr));
        screenGroupBox->setTitle(tr2i18n("Screen", nullptr));
#if QT_CONFIG(tooltip)
        screenToggleButton->setToolTip(tr2i18n("Toggle between fullscreen and each single screen.", nullptr));
#endif // QT_CONFIG(tooltip)
        screenToggleButton->setText(tr2i18n("Toggle Screen", nullptr));
#if QT_CONFIG(tooltip)
        controlsGroupBox->setToolTip(tr2i18n("Select the valid tablet area used for the selected screen space.", nullptr));
#endif // QT_CONFIG(tooltip)
        controlsGroupBox->setTitle(tr2i18n("Map Screen To", nullptr));
        fullTabletRadioButton->setText(tr2i18n("&Full Tablet", nullptr));
        tabletAreaRadioButton->setText(tr2i18n("&Tablet Area", nullptr));
#if QT_CONFIG(tooltip)
        forceProportionsButton->setToolTip(tr2i18n("Set the tablet area proportional to the selected screen area.", nullptr));
#endif // QT_CONFIG(tooltip)
        forceProportionsButton->setText(tr2i18n("Set Screen Proportions", nullptr));
        calibrateButton->setText(tr2i18n("Calibrate", nullptr));
        tabletGroupBox->setTitle(tr2i18n("Tablet", nullptr));
        warningIcon->setText(QString());
        warningLabel->setText(tr2i18n("This mapping can only be applied in absolute tracking mode.", nullptr));
        buttonLockProportions->setText(tr2i18n("Lock proportions", nullptr));
        fineTuneGroupBox->setTitle(tr2i18n("Tablet area fine tuning", nullptr));
#if QT_CONFIG(tooltip)
        lineEditWidth->setToolTip(tr2i18n("Width", nullptr));
#endif // QT_CONFIG(tooltip)
        labelHorizontalTune->setText(tr2i18n("Horizontal", nullptr));
#if QT_CONFIG(tooltip)
        lineEditX->setToolTip(tr2i18n("Left margin", nullptr));
#endif // QT_CONFIG(tooltip)
        labelVerticalTune->setText(tr2i18n("Vertical", nullptr));
#if QT_CONFIG(tooltip)
        lineEditY->setToolTip(tr2i18n("Top margin", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        lineEditHeight->setToolTip(tr2i18n("Height", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)TabletAreaSelectionView;
    } // retranslateUi

};

namespace Ui {
    class TabletAreaSelectionView: public Ui_TabletAreaSelectionView {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TABLETAREASELECTIONVIEW_H

