/********************************************************************************
** Form generated from reading UI file 'tabletpagewidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TABLETPAGEWIDGET_H
#define UI_TABLETPAGEWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_TabletPageWidget
{
public:
    QVBoxLayout *verticalLayout_9;
    QHBoxLayout *horizontalLayout_3;
    QGroupBox *trackingModeGroupBox;
    QVBoxLayout *verticalLayout_5;
    QRadioButton *trackAbsoluteRadioButton;
    QRadioButton *trackRelativeRadioButton;
    QSpacerItem *trackingFreeSpacer;
    QGroupBox *padMappingGroupBox;
    QVBoxLayout *verticalLayout_2;
    QPushButton *padMappingTabletButton;
    QHBoxLayout *trackingWarningLayout;
    QLabel *trackingWarningIcon;
    QLabel *trackingWarningLabel;
    QSpacerItem *padMappingFreeSpacer;
    QHBoxLayout *horizontalLayout_2;
    QGroupBox *rotationGroupBox;
    QVBoxLayout *verticalLayout;
    QComboBox *rotatationSelectionComboBox;
    QCheckBox *rotateWithScreenCheckBox;
    QCheckBox *rotateWithScreenInvertCheckBox;
    QSpacerItem *rotatationFreeSpacer;
    QWidget *widget;
    QSpacerItem *verticalFreeSpacer;

    void setupUi(QWidget *TabletPageWidget)
    {
        if (TabletPageWidget->objectName().isEmpty())
            TabletPageWidget->setObjectName("TabletPageWidget");
        TabletPageWidget->resize(790, 602);
        verticalLayout_9 = new QVBoxLayout(TabletPageWidget);
        verticalLayout_9->setObjectName("verticalLayout_9");
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        trackingModeGroupBox = new QGroupBox(TabletPageWidget);
        trackingModeGroupBox->setObjectName("trackingModeGroupBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(trackingModeGroupBox->sizePolicy().hasHeightForWidth());
        trackingModeGroupBox->setSizePolicy(sizePolicy);
        verticalLayout_5 = new QVBoxLayout(trackingModeGroupBox);
        verticalLayout_5->setObjectName("verticalLayout_5");
        trackAbsoluteRadioButton = new QRadioButton(trackingModeGroupBox);
        trackAbsoluteRadioButton->setObjectName("trackAbsoluteRadioButton");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(trackAbsoluteRadioButton->sizePolicy().hasHeightForWidth());
        trackAbsoluteRadioButton->setSizePolicy(sizePolicy1);
        trackAbsoluteRadioButton->setChecked(true);

        verticalLayout_5->addWidget(trackAbsoluteRadioButton);

        trackRelativeRadioButton = new QRadioButton(trackingModeGroupBox);
        trackRelativeRadioButton->setObjectName("trackRelativeRadioButton");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(trackRelativeRadioButton->sizePolicy().hasHeightForWidth());
        trackRelativeRadioButton->setSizePolicy(sizePolicy2);

        verticalLayout_5->addWidget(trackRelativeRadioButton);

        trackingFreeSpacer = new QSpacerItem(1, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        verticalLayout_5->addItem(trackingFreeSpacer);


        horizontalLayout_3->addWidget(trackingModeGroupBox);

        padMappingGroupBox = new QGroupBox(TabletPageWidget);
        padMappingGroupBox->setObjectName("padMappingGroupBox");
        sizePolicy.setHeightForWidth(padMappingGroupBox->sizePolicy().hasHeightForWidth());
        padMappingGroupBox->setSizePolicy(sizePolicy);
        verticalLayout_2 = new QVBoxLayout(padMappingGroupBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        padMappingTabletButton = new QPushButton(padMappingGroupBox);
        padMappingTabletButton->setObjectName("padMappingTabletButton");
        sizePolicy1.setHeightForWidth(padMappingTabletButton->sizePolicy().hasHeightForWidth());
        padMappingTabletButton->setSizePolicy(sizePolicy1);

        verticalLayout_2->addWidget(padMappingTabletButton);

        trackingWarningLayout = new QHBoxLayout();
        trackingWarningLayout->setObjectName("trackingWarningLayout");
        trackingWarningIcon = new QLabel(padMappingGroupBox);
        trackingWarningIcon->setObjectName("trackingWarningIcon");
        trackingWarningIcon->setMinimumSize(QSize(16, 16));
        trackingWarningIcon->setMaximumSize(QSize(16, 16));

        trackingWarningLayout->addWidget(trackingWarningIcon);

        trackingWarningLabel = new QLabel(padMappingGroupBox);
        trackingWarningLabel->setObjectName("trackingWarningLabel");
        trackingWarningLabel->setWordWrap(true);

        trackingWarningLayout->addWidget(trackingWarningLabel);


        verticalLayout_2->addLayout(trackingWarningLayout);

        padMappingFreeSpacer = new QSpacerItem(1, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        verticalLayout_2->addItem(padMappingFreeSpacer);


        horizontalLayout_3->addWidget(padMappingGroupBox);


        verticalLayout_9->addLayout(horizontalLayout_3);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        rotationGroupBox = new QGroupBox(TabletPageWidget);
        rotationGroupBox->setObjectName("rotationGroupBox");
        sizePolicy.setHeightForWidth(rotationGroupBox->sizePolicy().hasHeightForWidth());
        rotationGroupBox->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(rotationGroupBox);
        verticalLayout->setObjectName("verticalLayout");
        rotatationSelectionComboBox = new QComboBox(rotationGroupBox);
        rotatationSelectionComboBox->setObjectName("rotatationSelectionComboBox");

        verticalLayout->addWidget(rotatationSelectionComboBox);

        rotateWithScreenCheckBox = new QCheckBox(rotationGroupBox);
        rotateWithScreenCheckBox->setObjectName("rotateWithScreenCheckBox");

        verticalLayout->addWidget(rotateWithScreenCheckBox);

        rotateWithScreenInvertCheckBox = new QCheckBox(rotationGroupBox);
        rotateWithScreenInvertCheckBox->setObjectName("rotateWithScreenInvertCheckBox");
        rotateWithScreenInvertCheckBox->setEnabled(false);

        verticalLayout->addWidget(rotateWithScreenInvertCheckBox);

        rotatationFreeSpacer = new QSpacerItem(1, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        verticalLayout->addItem(rotatationFreeSpacer);


        horizontalLayout_2->addWidget(rotationGroupBox);

        widget = new QWidget(TabletPageWidget);
        widget->setObjectName("widget");
        sizePolicy.setHeightForWidth(widget->sizePolicy().hasHeightForWidth());
        widget->setSizePolicy(sizePolicy);

        horizontalLayout_2->addWidget(widget);


        verticalLayout_9->addLayout(horizontalLayout_2);

        verticalFreeSpacer = new QSpacerItem(1, 1, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_9->addItem(verticalFreeSpacer);


        retranslateUi(TabletPageWidget);
        QObject::connect(rotateWithScreenCheckBox, SIGNAL(stateChanged(int)), TabletPageWidget, SLOT(onAutoRotateChanged(int)));
        QObject::connect(rotateWithScreenInvertCheckBox, SIGNAL(stateChanged(int)), TabletPageWidget, SLOT(onProfileChanged()));
        QObject::connect(padMappingTabletButton, SIGNAL(clicked()), TabletPageWidget, SLOT(onTabletMappingClicked()));
        QObject::connect(rotatationSelectionComboBox, SIGNAL(currentIndexChanged(int)), TabletPageWidget, SLOT(onProfileChanged()));
        QObject::connect(trackAbsoluteRadioButton, SIGNAL(toggled(bool)), TabletPageWidget, SLOT(onTrackingModeAbsolute(bool)));
        QObject::connect(trackRelativeRadioButton, SIGNAL(toggled(bool)), TabletPageWidget, SLOT(onTrackingModeRelative(bool)));
        QObject::connect(rotatationSelectionComboBox, SIGNAL(currentIndexChanged(int)), TabletPageWidget, SLOT(onRotationChanged()));
        QObject::connect(rotateWithScreenCheckBox, SIGNAL(stateChanged(int)), TabletPageWidget, SLOT(onRotationChanged()));
        QObject::connect(rotateWithScreenInvertCheckBox, SIGNAL(stateChanged(int)), TabletPageWidget, SLOT(onRotationChanged()));

        QMetaObject::connectSlotsByName(TabletPageWidget);
    } // setupUi

    void retranslateUi(QWidget *TabletPageWidget)
    {
#if QT_CONFIG(tooltip)
        trackingModeGroupBox->setToolTip(tr2i18n("Defines how the cursor movement mode will be used.", nullptr));
#endif // QT_CONFIG(tooltip)
        trackingModeGroupBox->setTitle(tr2i18n("Stylus Tracking Mode", nullptr));
        trackAbsoluteRadioButton->setText(tr2i18n("&Map to Screen (Absolute Mode)", nullptr));
        trackRelativeRadioButton->setText(tr2i18n("Map &to Cursor (Relative Mode)", nullptr));
        padMappingGroupBox->setTitle(tr2i18n("Tablet Mapping", nullptr));
#if QT_CONFIG(tooltip)
        padMappingTabletButton->setToolTip(tr2i18n("Allows one to specify the tablet area for different screen selections in absolute cursor mode.", nullptr));
#endif // QT_CONFIG(tooltip)
        padMappingTabletButton->setText(tr2i18n("Map Tablet Area to Screen", nullptr));
        trackingWarningLabel->setText(tr2i18n("Your currently selected mapping can not be applied in relative tracking mode.", nullptr));
#if QT_CONFIG(tooltip)
        rotationGroupBox->setToolTip(tr2i18n("Changes the orientation of the tablet.", nullptr));
#endif // QT_CONFIG(tooltip)
        rotationGroupBox->setTitle(tr2i18n("Orientation", nullptr));
#if QT_CONFIG(tooltip)
        rotateWithScreenCheckBox->setToolTip(tr2i18n("If enabled, the tablet rotates together with the screen.", nullptr));
#endif // QT_CONFIG(tooltip)
        rotateWithScreenCheckBox->setText(tr2i18n("Auto-Rotate with Screen", nullptr));
#if QT_CONFIG(tooltip)
        rotateWithScreenInvertCheckBox->setToolTip(tr2i18n("If enabled the automatic tablet rotation for clockwise and counterclockwise rotations will be inverted.", nullptr));
#endif // QT_CONFIG(tooltip)
        rotateWithScreenInvertCheckBox->setText(tr2i18n("Invert Auto-Rotation", nullptr));
        (void)TabletPageWidget;
    } // retranslateUi

};

namespace Ui {
    class TabletPageWidget: public Ui_TabletPageWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TABLETPAGEWIDGET_H

