/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Wacom.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "wacomadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class WacomAdaptor
 */

WacomAdaptor::WacomAdaptor(Wacom::DBusTabletService *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

WacomAdaptor::~WacomAdaptor()
{
    // destructor
}

QStringList WacomAdaptor::getDeviceList(const QString &tabletId)
{
    // handle method call org.kde.Wacom.getDeviceList
    return parent()->getDeviceList(tabletId);
}

QString WacomAdaptor::getDeviceName(const QString &tabletId, const QString &device)
{
    // handle method call org.kde.Wacom.getDeviceName
    return parent()->getDeviceName(tabletId, device);
}

QString WacomAdaptor::getInformation(const QString &tabletId, const QString &info)
{
    // handle method call org.kde.Wacom.getInformation
    return parent()->getInformation(tabletId, info);
}

QString WacomAdaptor::getProfile(const QString &tabletId)
{
    // handle method call org.kde.Wacom.getProfile
    return parent()->getProfile(tabletId);
}

QStringList WacomAdaptor::getProfileRotationList(const QString &tabletId)
{
    // handle method call org.kde.Wacom.getProfileRotationList
    return parent()->getProfileRotationList(tabletId);
}

QString WacomAdaptor::getProperty(const QString &tabletId, const QString &device, const QString &param)
{
    // handle method call org.kde.Wacom.getProperty
    return parent()->getProperty(tabletId, device, param);
}

QStringList WacomAdaptor::getTabletList()
{
    // handle method call org.kde.Wacom.getTabletList
    return parent()->getTabletList();
}

QString WacomAdaptor::getTouchSensorId(const QString &tabletId)
{
    // handle method call org.kde.Wacom.getTouchSensorId
    return parent()->getTouchSensorId(tabletId);
}

bool WacomAdaptor::hasPadButtons(const QString &tabletId)
{
    // handle method call org.kde.Wacom.hasPadButtons
    return parent()->hasPadButtons(tabletId);
}

bool WacomAdaptor::isAvailable(const QString &tabletId)
{
    // handle method call org.kde.Wacom.isAvailable
    return parent()->isAvailable(tabletId);
}

bool WacomAdaptor::isTouchSensor(const QString &tabletId)
{
    // handle method call org.kde.Wacom.isTouchSensor
    return parent()->isTouchSensor(tabletId);
}

QStringList WacomAdaptor::listProfiles(const QString &tabletId)
{
    // handle method call org.kde.Wacom.listProfiles
    return parent()->listProfiles(tabletId);
}

void WacomAdaptor::setProfile(const QString &tabletId, const QString &profile)
{
    // handle method call org.kde.Wacom.setProfile
    parent()->setProfile(tabletId, profile);
}

void WacomAdaptor::setProfileRotationList(const QString &tabletId, const QStringList &in1)
{
    // handle method call org.kde.Wacom.setProfileRotationList
    parent()->setProfileRotationList(tabletId, in1);
}

void WacomAdaptor::setProperty(const QString &tabletId, const QString &device, const QString &param, const QString &value)
{
    // handle method call org.kde.Wacom.setProperty
    parent()->setProperty(tabletId, device, param, value);
}


#include "moc_wacomadaptor.cpp"
