/****************************************************************************
** Meta object code from reading C++ file 'dbustabletservice.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../wacomtablet-6.7.3/src/kded/dbustabletservice.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dbustabletservice.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Wacom17DBusTabletServiceE_t {};
} // unnamed namespace

template <> constexpr inline auto Wacom::DBusTabletService::qt_create_metaobjectdata<qt_meta_tag_ZN5Wacom17DBusTabletServiceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Wacom::DBusTabletService",
        "D-Bus Interface",
        "org.kde.Wacom",
        "tabletAdded",
        "",
        "tabletId",
        "tabletRemoved",
        "profileChanged",
        "profile",
        "getTabletList",
        "getDeviceList",
        "getDeviceName",
        "device",
        "getInformation",
        "info",
        "getProfile",
        "getProperty",
        "deviceType",
        "property",
        "hasPadButtons",
        "isAvailable",
        "listProfiles",
        "setProfile",
        "setProperty",
        "value",
        "getProfileRotationList",
        "setProfileRotationList",
        "rotationList",
        "getTouchSensorId",
        "isTouchSensor",
        "onProfileChanged",
        "onTabletAdded",
        "TabletInformation",
        "onTabletRemoved"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'tabletAdded'
        QtMocHelpers::SignalData<void(const QString &)>(3, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'tabletRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(6, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'profileChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(7, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 8 },
        }}),
        // Slot 'getTabletList'
        QtMocHelpers::SlotData<const QStringList() const>(9, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QStringList),
        // Slot 'getDeviceList'
        QtMocHelpers::SlotData<const QStringList(const QString &) const>(10, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QStringList, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'getDeviceName'
        QtMocHelpers::SlotData<QString(const QString &, const QString &) const>(11, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 12 },
        }}),
        // Slot 'getInformation'
        QtMocHelpers::SlotData<QString(const QString &, const QString &) const>(13, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 14 },
        }}),
        // Slot 'getProfile'
        QtMocHelpers::SlotData<QString(const QString &) const>(15, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'getProperty'
        QtMocHelpers::SlotData<QString(const QString &, const QString &, const QString &) const>(16, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 17 }, { QMetaType::QString, 18 },
        }}),
        // Slot 'hasPadButtons'
        QtMocHelpers::SlotData<bool(const QString &) const>(19, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'isAvailable'
        QtMocHelpers::SlotData<bool(const QString &) const>(20, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'listProfiles'
        QtMocHelpers::SlotData<QStringList(const QString &)>(21, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QStringList, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'setProfile'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(22, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 8 },
        }}),
        // Slot 'setProperty'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &, const QString &)>(23, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 17 }, { QMetaType::QString, 18 }, { QMetaType::QString, 24 },
        }}),
        // Slot 'getProfileRotationList'
        QtMocHelpers::SlotData<QStringList(const QString &)>(25, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QStringList, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'setProfileRotationList'
        QtMocHelpers::SlotData<void(const QString &, const QStringList &)>(26, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QStringList, 27 },
        }}),
        // Slot 'getTouchSensorId'
        QtMocHelpers::SlotData<QString(const QString &)>(28, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'isTouchSensor'
        QtMocHelpers::SlotData<bool(const QString &)>(29, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'onProfileChanged'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(30, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 8 },
        }}),
        // Slot 'onTabletAdded'
        QtMocHelpers::SlotData<void(const TabletInformation &)>(31, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 14 },
        }}),
        // Slot 'onTabletRemoved'
        QtMocHelpers::SlotData<void(const QString &)>(33, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DBusTabletService, qt_meta_tag_ZN5Wacom17DBusTabletServiceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Wacom::DBusTabletService::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Wacom17DBusTabletServiceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Wacom17DBusTabletServiceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Wacom17DBusTabletServiceE_t>.metaTypes,
    nullptr
} };

void Wacom::DBusTabletService::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DBusTabletService *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->tabletAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->tabletRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->profileChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: { QStringList _r = _t->getTabletList();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 4: { QStringList _r = _t->getDeviceList((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 5: { QString _r = _t->getDeviceName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 6: { QString _r = _t->getInformation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 7: { QString _r = _t->getProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 8: { QString _r = _t->getProperty((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->hasPadButtons((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->isAvailable((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { QStringList _r = _t->listProfiles((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->setProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 13: _t->setProperty((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 14: { QStringList _r = _t->getProfileRotationList((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->setProfileRotationList((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 16: { QString _r = _t->getTouchSensorId((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 17: { bool _r = _t->isTouchSensor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->onProfileChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 19: _t->onTabletAdded((*reinterpret_cast<std::add_pointer_t<TabletInformation>>(_a[1]))); break;
        case 20: _t->onTabletRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DBusTabletService::*)(const QString & )>(_a, &DBusTabletService::tabletAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusTabletService::*)(const QString & )>(_a, &DBusTabletService::tabletRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusTabletService::*)(const QString & , const QString & )>(_a, &DBusTabletService::profileChanged, 2))
            return;
    }
}

const QMetaObject *Wacom::DBusTabletService::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Wacom::DBusTabletService::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Wacom17DBusTabletServiceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Wacom::DBusTabletService::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void Wacom::DBusTabletService::tabletAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Wacom::DBusTabletService::tabletRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Wacom::DBusTabletService::profileChanged(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}
QT_WARNING_POP
